searchData={"items":[{"type":"module","title":"FatEcto","doc":"","ref":"FatEcto.html"},{"type":"module","title":"Description - FatEcto","doc":"Currently it's supporting following **query functions**:\n\n- where\n- where_or\n- select\n- joins\n- order_by\n- include\n- group_by\n- aggregate\n- distinct","ref":"FatEcto.html#module-description"},{"type":"module","title":"Where - FatEcto","doc":"_Where_ include methods from [Ecto.Query.API](https://hexdocs.pm/ecto/Ecto.Query.API.html). These are the options _where_ supports.\n\n| function         | Description                                                                                                        |\n| ---------------- | ------------------------------------------------------------------------------------------------------------------ |\n| like             | matches the substring with the attribute in the database. `\"$like\"` .                                              |\n| notlike          | return result where value in the substring doesn't match. `\"$not_like\"` .                                          |\n| ilike            | matches the substring passed with the attribute in the database `\"$ilike\"` .                                       |\n| notiLike         | return result where value in the substring doesn't match.`\"$not_ilike\"`.                                           |\n| lessthan         | fetch result where value is less than the numerical value `\"$lt\"` (also apply on non_numerical fields).            |\n| lessthanequal    | fetch result where value is less than equal to the numerical value `\"$lte\"` (also apply on non_numerical fields.   |\n| greaterthan      | fetch result where value is greater than the numerical value `\"$gt`\" (also apply on non_numerical fields.)         |\n| greaterthanequal | fetch result where value is greater than equal to the numerical value `\"gte\"` (also apply on non_numerical fields. |\n| between          | [] ,fetch the result where value is between the provided attributes. `\"$between\"`.                                  |\n| betweenequal     | [] ,fetch the result where value is equal and between the provided attributes. `\"$between_equal\"`.                                  |\n| notbetween       | [] ,fetch the result where value is not between the provided list attributes. `\"$not_between\"`.                    |\n| notbetweenequal  | [] ,fetch the result where value is not equal and between the provided list attributes. `\"$not_between_equal\"`.                    |\n| in               | [] ,fetch result where value is in the the provided list attributes. `\"$in\"` .                                    |\n| notin            | [] ,fetch result where value is not in the the provided list attributes. `\"$not_in\"` .                             |\n| contains         | [] ,fetch the key from the josnb field and see if it contains the value. `\"$contains\"` .                             |\n| containany       | [] ,fetch the key from the josnb field and see if it contains any of the values passed. `\"$contains_any\"` .                             |\n| isnil            | value is nil. `\"nil\"`.                                                                                             |\n| notisnil        | value is not nil. `\"$not_null\"` .                                                                                  |\n\n#### Example:\n\n```elixir\n    query_ opts = %{\n     \"$where\" => %{\n        \"name\" => \"%Joh%\",\n        \"location\" => nil,\n        \"$not_null\" => [\"total_staff\", \"address\", \"phone\"],\n        \"rating\" => \"$not_null\",\n        \"total_staff\" => %{\"$between\" => [1, 3]}\n      }\n    }\n\n   iex> build(FatEcto.FatHospital, query_opts)\n   iex> #Ecto.Query  ^1 and f0.total_staff < ^3 and\n          (not is_nil(f0.rating) and\n             (f0.name == ^\"%Joh%\" and\n                (is_nil(f0.location) and\n                   (not is_nil(f0.phone) and\n                      (not is_nil(f0.address) and (not is_nil(f0.total_staff) and ^true))))))\n         )>\n\n   query_ opts = %{\n      \"$where\" => %{\"rating\" => %{\"$lte\" => \"$total_staff\"}}\n    }\n\n   iex> build(FatEcto.FatHospital, opts)\n   iex> #Ecto.Query \n```","ref":"FatEcto.html#module-where"},{"type":"module","title":"Where_or - FatEcto","doc":"Add _or_ clause in the _where_ when building a query._where_or_ is useful when you want to add multiple _or_ conditions in the where conditional.","ref":"FatEcto.html#module-where_or"},{"type":"module","title":"Example: - FatEcto","doc":"```elixir\nquery_opts = %{\n    \"$where\" => %{\n      \"$or\" => %{\n        \"name\" => %{\"$like\" => \"%Joh%\"},\n        \"total_staff\" => %{\"$between_equal\" => [5, 7]}\n      }\n    }\n  }\niex> build(FatEcto.FatHospital, query_opts)\niex> #Ecto.Query = ^5 and f0.total_staff <= ^7) or\n          (like(fragment(\"(?)::TEXT\", f0.name), ^\"%Joh%\") or ^true))>\n```","ref":"FatEcto.html#module-example"},{"type":"module","title":"Select - FatEcto","doc":"_Select_ fields from the schema as well as from the associated schemas. You can pass fields as a list or in a map.\n\n\n#### Example:\n\n```elixir\nquery_opts = %{\n    \"$select\" => [\"name\", \"location\", \"rating\"],\n    \"$order\" => %{\"id\" => \"$desc\"}\n}\niex> build(FatEcto.FatHospital, query_opts)\niex> #Ecto.Query \n\nquery_ opts = %{\n    \"$select\" => %{\n      \"$fields\" => [\"name\", \"location\", \"rating\"],\n      \"fat_rooms\" => [\"beds\", \"capacity\"]\n    },\n    \"$where\" => %{\"id\" => 2}\n}\niex> build(FatEcto.FatHospital, query_opts)\niex> #Ecto.Query \n```","ref":"FatEcto.html#module-select"},{"type":"module","title":"Joins - FatEcto","doc":"_Joins_ with another table on the type of join you passed in the params. It supports _where_ , _select_, _order_by_, _group_by_ . Additionally, it also supports _additional_on_clauses_. Supported Join types are:\n\n- inner\n- left\n- right\n- full\n\n#### Example\n\n```elixir\nquery_opts = %{\n    \"$select\" => %{\"$fields\" => [\"designation\", \"experience_years\"]},\n    \"$full_join\" => %{\n      \"fat_patients\" => %{\n        \"$on_field\" => \"id\",\n        \"$on_table_field\" => \"doctor_id\",\n        \"$where\" => %{\"location\" => \"bullavard\"},\n        \"$select\" => [\"name\", \"prescription\"],\n        \"$order\" => %{\"appointments_count\" => \"$asc\"},\n        \"$group\" => \"experience_years\"\n      }\n    }\n  }\niex> build(FatEcto.FatDoctor, query_opts)\niex> #Ecto.Query \n\nquery_opts = %{\n    \"$inner_join\" => %{\n      \"fat_rooms\" => %{\n        \"$on_field\" => \"id\",\n        \"$on_table_field\" => \"hospital_id\",\n        \"$additional_on_clauses\" => %{\n          \"rating\" => %{\"$not_between\" => [1, 3]},\n          \"total_staff\" => %{\"$not_between_equal\" => [4, 5]}\n        },\n        \"$select\" => [\"beds\", \"capacity\", \"level\"],\n        \"$where\" => %{\"incharge\" => \"John\"}\n      }\n    },\n    \"$where\" => %{\"rating\" => 3}\n  }\niex> build(FatEcto.FatHospital, query_opts)\niex> #Ecto.Query = ^5) and ((h.rating < ^1 or h.rating > ^3) and ^true)),\n       where: r.incharge == ^\"John\" and ^true,\n       select: %{^\"fat_rooms\" => map(r, [:beds, :capacity, :level])}\n      )>\n```","ref":"FatEcto.html#module-joins"},{"type":"module","title":"Order_by - FatEcto","doc":"_order_by_ returns the query by sort the results as _asc_ or _desc_ order.\n\n#### Example\n\n```elixir\nquery_opts = %{\n      \"$select\" => %{\n        \"$fields\" => [\"name\", \"location\", \"rating\"],\n        \"fat_rooms\" => [\"beds\", \"capacity\"]\n      },\n      \"$order\" => %{\"id\" => \"$desc\"}\n    }\n    iex> build(FatEcto.FatHospital, opts)\n    iex> #Ecto.Query \n\nquery_ opts = %{\n      \"$select\" => [\"name\", \"location\", \"rating\"],\n      \"$order\" => %{\"id\" => \"$asc\"}\n    }\niex> build(FatEcto.FatHospital, query_opts)\niex> #Ecto.Query \n```","ref":"FatEcto.html#module-order_by"},{"type":"module","title":"Include - FatEcto","doc":"_include_ preload tables based on the conditions passed in the query params. You can specify the _where_ , _order_by_ , _join_, _group_by_ in the include for the associated tables. You can also use nested _include_ to preload nested relationships.\n\n#### Example\n\n```elixir\nquery_opts = %{\n    \"$include\" => %{\n      \"fat_hospitals\" => %{\"$include\" => %{\"fat_rooms\" => %{\"$include\" => [\"fat_hospital\", \"fat_beds\"]}}},\n      \"fat_patients\" => %{\n        \"$include\" => %{\n          \"fat_doctors\" => %{\n            \"$include\" => %{\"fat_hospitals\" => %{\"$include\" => \"fat_rooms\", \"$where\" => %{\"name\" => \"Joh\"}}}\n          }\n        }\n      }\n    }\n  }\niex> build(FatEcto.FatDoctor, query_opts)\niex> #Ecto.Query \n```","ref":"FatEcto.html#module-include"},{"type":"module","title":"Group_By - FatEcto","doc":"_group_by_ groups together rows from the schema that have the same values in the given fields. It also supports multiple _group_by_ fields in a list.\n\n#### Example\n\n```elixir\nquery_opts = %{\n      \"$inner_join\" => %{\n        \"fat_rooms\" => %{\n          \"$on_field\" => \"id\",\n          \"$on_table_field\" => \"hospital_id\",\n          \"$select\" => [\"beds\", \"capacity\", \"level\"],\n          \"$where\" => %{\"incharge\" => \"John\"}\n        }\n      },\n      \"$where\" => %{\"rating\" => 3},\n      \"$group\" => [\"rating\", \"total_staff\"]\n    }\n\niex> build(FatEcto.FatHospital, query_opts)\niex> #Ecto.Query \n\nquery_opts = %{\n      \"$select\" => [\"name\", \"location\", \"rating\"],\n      \"$order\" => %{\"id\" => \"$asc\"},\n      \"$group\" => \"rating\"\n    }\n\niex>  build(FatEcto.FatHospital, query_opts)\niex>  #Ecto.Query \n```","ref":"FatEcto.html#module-group_by"},{"type":"module","title":"Aggregate - FatEcto","doc":"_Aggregate_ supports aggregate methods that can be passed as a string or a list.\n\n| function         | Description                                                                                                        |\n| ---------------- | ------------------------------------------------------------------------------------------------------------------ |\n| max              | Select the maximum value from the records matching the query. `\"$max\"`.                                            |\n| min              | Select the minimum value from the records matching the query. `\"$min\"`.                                            |\n| avg              | Calculates the average from the records matching the query. `\"$avg\"`.                                              |\n| count            | Counts the given entry based on the query passed. `\"$count\"`                                                       |\n| count_distinct   | Counts the distinct values in given entry based on the query passed.`\"$count_distinct\"`.                           |\n| sum              | Calculates the sum for the given entry based on the query passed. `$sum`.                                          |\n\n#### Example\n\n```elixir\nquery_opts = %{\n    \"$aggregate\" => %{\"$max\" => \"nurses\", \"$min\" => \"capacity\"},\n    \"$where\" => %{\"capacity\" => 5},\n    \"$group\" => \"capacity\"\n  }\niex>  build(FatEcto.FatRoom, query_opts)\niex>  #Ecto.Query \n\nquery_opts = %{\n    \"$aggregate\" => %{\"$sum\" => [\"nurses\", \"beds\"], \"$avg\" => [\"capacity\", \"nurses\"]},\n    \"$where\" => %{\"capacity\" => 5},\n    \"$group\" => \"capacity\"\n  }\niex>  build(FatEcto.FatRoom, query_opts)\niex>  #Ecto.Query \n\n```","ref":"FatEcto.html#module-aggregate"},{"type":"module","title":"Distinct - FatEcto","doc":"Adds _distinct_ query expression to avoid duplication of records. You can pass the distinct _field name_ or _true_.\n#### Example\n\n```elixir\nquery_opts = %{\n    \"$distinct\" => \"name\"\n  }\n\niex> build(FatEcto.FatHospital, opts)\niex> Ecto.Query \n\nquery_opts = %{\n    \"$distinct\" => true\n  }\n\niex> build(FatEcto.FatHospital, opts)\niex> Ecto.Query \n```\nYou have to pass ```\"$distinct_nested => true\"``` alongwith ```\"$distinct => true\"```  if there are multiple _order_by_ clauses in your query.","ref":"FatEcto.html#module-distinct"},{"type":"module","title":"Paginator - FatEcto","doc":"_FAT_ allows to restrict the number of results you want to return from the repo. You can define _limit_ as limit and _offset_ as skip in the config.\n\n#### Example\n\n```elixir\nopts = %{\n      \"$select\" => [\"name\", \"location\", \"rating\"],\n      \"$order\" => %{\"id\" => \"$asc\"},\n      \"$group\" => \"rating\",\n      \"$limit\" => 20,\n      \"$skip\" => 0\n    }\n```\n\nIf no limit is defined then FAT automatically uses `default_limit`. For this to work you have to define the default_limit in fat_ecto config.\nsee docs for more info.","ref":"FatEcto.html#module-paginator"},{"type":"module","title":"Blacklist params - FatEcto","doc":"Fat ecto provides you control to restrict access to specific fields of different tables in your database. You have to set these fields in your fat ecto config. If these fields are present in the query, fat ecto will raise an error.\n\n#### Example\n\n```elixir\nquery_opts = %{\n    \"$select\" => %{\n      \"$fields\" => [\"name\", \"purpose\", \"description\"],\n      \"fat_beds\" => [\"purpose\", \"description\"]\n    },\n    \"$where\" => %{\"id\" => room.id}\n  }\niex> Query.build!(FatEcto.FatRoom, query_opts)\niex>  ** (ArgumentError) the fields [\"description\"] of fat_rooms are not allowed in the query\n```","ref":"FatEcto.html#module-blacklist-params"},{"type":"module","title":"FatEcto.DataSanitizer","doc":"Provides functionality to sanitize records and convert data into views.\n\nThis module can be used to clean up records by removing sensitive data, masking specific fields,\nand customizing the output based on options.","ref":"FatEcto.DataSanitizer.html"},{"type":"module","title":"FatEcto.FatContext","doc":"Provides a set of utility functions to simplify common Ecto operations such as querying, creating, updating, and deleting records.\n\nThis module is designed to be used within a context module to provide a consistent and easy-to-use API for interacting with your database.","ref":"FatEcto.FatContext.html"},{"type":"module","title":"Usage - FatEcto.FatContext","doc":"defmodule MyApp.UserContext do\n      use FatEcto.FatContext, repo: MyApp.Repo\n\n      # Custom functions can be added here\n    end\n\nNow you can use the functions provided by `FatEcto.FatContext` within `MyApp.UserContext`.","ref":"FatEcto.FatContext.html#module-usage"},{"type":"module","title":"FatEcto.FatHelper","doc":"Provides utility functions for FatEcto, including handling pagination limits, skip values,\ndynamic binding, and preloading associations.","ref":"FatEcto.FatHelper.html"},{"type":"function","title":"FatEcto.FatHelper.dynamic_binding/1","doc":"Adds dynamic binding information to a map.","ref":"FatEcto.FatHelper.html#dynamic_binding/1"},{"type":"function","title":"Parameters - FatEcto.FatHelper.dynamic_binding/1","doc":"- `map`: The map to process.","ref":"FatEcto.FatHelper.html#dynamic_binding/1-parameters"},{"type":"function","title":"Examples - FatEcto.FatHelper.dynamic_binding/1","doc":"iex> FatEcto.FatHelper.dynamic_binding(%{\"$include\" => %{\"key\" => \"value\"}})\n    %{\"$include\" => %{\"key\" => \"value\", \"$binding\" => :first}}","ref":"FatEcto.FatHelper.html#dynamic_binding/1-examples"},{"type":"function","title":"FatEcto.FatHelper.dynamic_preloading/1","doc":"Dynamically preloads associations based on a map.","ref":"FatEcto.FatHelper.html#dynamic_preloading/1"},{"type":"function","title":"Parameters - FatEcto.FatHelper.dynamic_preloading/1","doc":"- `map`: The map containing preloading instructions.","ref":"FatEcto.FatHelper.html#dynamic_preloading/1-parameters"},{"type":"function","title":"Examples - FatEcto.FatHelper.dynamic_preloading/1","doc":"iex> FatEcto.FatHelper.dynamic_preloading(%{\"posts\" => %{\"$include\" => \"comments\"}})\n    [posts: :comments]","ref":"FatEcto.FatHelper.html#dynamic_preloading/1-examples"},{"type":"function","title":"FatEcto.FatHelper.fat_ecto_reserve_field?/1","doc":"Determines if a value is a reserved field in FatEcto.","ref":"FatEcto.FatHelper.html#fat_ecto_reserve_field?/1"},{"type":"function","title":"Parameters - FatEcto.FatHelper.fat_ecto_reserve_field?/1","doc":"- `value`: The value to check.","ref":"FatEcto.FatHelper.html#fat_ecto_reserve_field?/1-parameters"},{"type":"function","title":"Examples - FatEcto.FatHelper.fat_ecto_reserve_field?/1","doc":"iex> FatEcto.FatHelper.fat_ecto_reserve_field?(\"$include\")\n    true","ref":"FatEcto.FatHelper.html#fat_ecto_reserve_field?/1-examples"},{"type":"function","title":"FatEcto.FatHelper.get_limit_bounds/1","doc":"Returns the maximum and default limit values based on the provided options.","ref":"FatEcto.FatHelper.html#get_limit_bounds/1"},{"type":"function","title":"Parameters - FatEcto.FatHelper.get_limit_bounds/1","doc":"- `options`: A keyword list or map containing `max_limit` and `default_limit`.","ref":"FatEcto.FatHelper.html#get_limit_bounds/1-parameters"},{"type":"function","title":"Examples - FatEcto.FatHelper.get_limit_bounds/1","doc":"iex> FatEcto.FatHelper.get_limit_bounds(max_limit: 50, default_limit: 10)\n    {50, 10}","ref":"FatEcto.FatHelper.html#get_limit_bounds/1-examples"},{"type":"function","title":"FatEcto.FatHelper.get_limit_value/2","doc":"Extracts and validates the limit value from the given parameters.","ref":"FatEcto.FatHelper.html#get_limit_value/2"},{"type":"function","title":"Parameters - FatEcto.FatHelper.get_limit_value/2","doc":"- `params`: A keyword list containing the `:limit` value.\n- `options`: A keyword list or map containing `max_limit` and `default_limit`.","ref":"FatEcto.FatHelper.html#get_limit_value/2-parameters"},{"type":"function","title":"Examples - FatEcto.FatHelper.get_limit_value/2","doc":"iex> FatEcto.FatHelper.get_limit_value([limit: 15], max_limit: 50, default_limit: 10)\n    {15, []}","ref":"FatEcto.FatHelper.html#get_limit_value/2-examples"},{"type":"function","title":"FatEcto.FatHelper.get_module_options/3","doc":"Merges module-specific options with global and root-level configurations.","ref":"FatEcto.FatHelper.html#get_module_options/3"},{"type":"function","title":"Parameters - FatEcto.FatHelper.get_module_options/3","doc":"- `options`: A keyword list of options.\n- `module`: The module for which options are being configured.\n- `defaults`: Default options to merge.","ref":"FatEcto.FatHelper.html#get_module_options/3-parameters"},{"type":"function","title":"Examples - FatEcto.FatHelper.get_module_options/3","doc":"iex> FatEcto.FatHelper.get_module_options([max_limit: 50], MyApp.MyContext)\n    [max_limit: 50, default_limit: 10]","ref":"FatEcto.FatHelper.html#get_module_options/3-examples"},{"type":"function","title":"FatEcto.FatHelper.get_primary_keys/1","doc":"Retrieves the primary keys for a given query.","ref":"FatEcto.FatHelper.html#get_primary_keys/1"},{"type":"function","title":"Parameters - FatEcto.FatHelper.get_primary_keys/1","doc":"- `query`: The Ecto query.","ref":"FatEcto.FatHelper.html#get_primary_keys/1-parameters"},{"type":"function","title":"Examples - FatEcto.FatHelper.get_primary_keys/1","doc":"iex> FatEcto.FatHelper.get_primary_keys(from(u in User))\n    [:id]","ref":"FatEcto.FatHelper.html#get_primary_keys/1-examples"},{"type":"function","title":"FatEcto.FatHelper.get_skip_value/1","doc":"Extracts and validates the skip value from the given parameters.","ref":"FatEcto.FatHelper.html#get_skip_value/1"},{"type":"function","title":"Parameters - FatEcto.FatHelper.get_skip_value/1","doc":"- `params`: A keyword list containing the `:skip` value.","ref":"FatEcto.FatHelper.html#get_skip_value/1-parameters"},{"type":"function","title":"Examples - FatEcto.FatHelper.get_skip_value/1","doc":"iex> FatEcto.FatHelper.get_skip_value(skip: 20)\n    {20, []}","ref":"FatEcto.FatHelper.html#get_skip_value/1-examples"},{"type":"function","title":"FatEcto.FatHelper.model_related_owner/2","doc":"Retrieves the owner and related association details for a given model and relation.","ref":"FatEcto.FatHelper.html#model_related_owner/2"},{"type":"function","title":"Parameters - FatEcto.FatHelper.model_related_owner/2","doc":"- `model`: The Ecto model.\n- `relation_name`: The name of the association.","ref":"FatEcto.FatHelper.html#model_related_owner/2-parameters"},{"type":"function","title":"Examples - FatEcto.FatHelper.model_related_owner/2","doc":"iex> FatEcto.FatHelper.model_related_owner(MyApp.User, :posts)\n    %{owner: MyApp.User, owner_key: :user_id, related: MyApp.Post, related_key: :id}","ref":"FatEcto.FatHelper.html#model_related_owner/2-examples"},{"type":"function","title":"FatEcto.FatHelper.remove_conflicting_order_by/2","doc":"Removes conflicting `order_by` clauses from a query.","ref":"FatEcto.FatHelper.html#remove_conflicting_order_by/2"},{"type":"function","title":"Parameters - FatEcto.FatHelper.remove_conflicting_order_by/2","doc":"- `queryable`: The Ecto query.\n- `distinct`: The distinct clause.","ref":"FatEcto.FatHelper.html#remove_conflicting_order_by/2-parameters"},{"type":"function","title":"Examples - FatEcto.FatHelper.remove_conflicting_order_by/2","doc":"iex> FatEcto.FatHelper.remove_conflicting_order_by(from(u in User), nil)\n    #Ecto.Query","ref":"FatEcto.FatHelper.html#remove_conflicting_order_by/2-examples"},{"type":"function","title":"FatEcto.FatHelper.string_to_atom/1","doc":"Converts a string to an atom.","ref":"FatEcto.FatHelper.html#string_to_atom/1"},{"type":"function","title":"Parameters - FatEcto.FatHelper.string_to_atom/1","doc":"- `str`: The string to convert.","ref":"FatEcto.FatHelper.html#string_to_atom/1-parameters"},{"type":"function","title":"Examples - FatEcto.FatHelper.string_to_atom/1","doc":"iex> FatEcto.FatHelper.string_to_atom(\"example\")\n    :example","ref":"FatEcto.FatHelper.html#string_to_atom/1-examples"},{"type":"function","title":"FatEcto.FatHelper.string_to_existing_atom/1","doc":"Converts a string to an existing atom.","ref":"FatEcto.FatHelper.html#string_to_existing_atom/1"},{"type":"function","title":"Parameters - FatEcto.FatHelper.string_to_existing_atom/1","doc":"- `str`: The string to convert.","ref":"FatEcto.FatHelper.html#string_to_existing_atom/1-parameters"},{"type":"function","title":"Examples - FatEcto.FatHelper.string_to_existing_atom/1","doc":"iex> FatEcto.FatHelper.string_to_existing_atom(\"example\")\n    :example","ref":"FatEcto.FatHelper.html#string_to_existing_atom/1-examples"},{"type":"module","title":"FatEcto.FatPaginator","doc":"Provides pagination functionality for Ecto queries.\n\nThis module can be used to paginate query results by specifying `limit` and `skip` parameters.\nIt also supports counting the total number of records for pagination metadata.","ref":"FatEcto.FatPaginator.html"},{"type":"module","title":"Usage - FatEcto.FatPaginator","doc":"defmodule MyApp.MyContext do\n      use FatEcto.FatPaginator, repo: MyApp.Repo\n\n      # Custom functions can be added here\n    end\n\nNow you can use the `paginate/2` function within `MyApp.MyContext`.","ref":"FatEcto.FatPaginator.html#module-usage"},{"type":"module","title":"FatEcto.FatQuery.FatDynamics","doc":"Builds a `where query` using dynamics.","ref":"FatEcto.FatQuery.FatDynamics.html"},{"type":"module","title":"Parameters - FatEcto.FatQuery.FatDynamics","doc":"- `queryable`   - Ecto Queryable that represents your schema name, table name or query.\n  - `query_opts`  - Where query options as a map.","ref":"FatEcto.FatQuery.FatDynamics.html#module-parameters"},{"type":"module","title":"Examples - FatEcto.FatQuery.FatDynamics","doc":"iex> query_opts = %{\n    ...>    \"$select\" => %{\n    ...>     \"$fields\" => [\"name\", \"location\", \"rating\"]\n    ...>    },\n    ...>   \"$where\" => %{\n    ...>      \"name\" => \"%John%\",\n    ...>      \"location\" => nil,\n    ...>      \"rating\" => \"$not_null\",\n    ...>      \"total_staff\" => %{\"$between\" => [1, 3]}\n    ...>    }\n    ...>  }\n    iex> Elixir.MyApp.Query.build!(FatEcto.FatHospital, query_opts)\n    #Ecto.Query  ^1 and f0.total_staff < ^3 and\n(not is_nil(f0.rating) and (f0.name == ^\"%John%\" and (is_nil(f0.location) and ^true))), select: map(f0, [:name, :location, :rating])>","ref":"FatEcto.FatQuery.FatDynamics.html#module-examples"},{"type":"module","title":"Options - FatEcto.FatQuery.FatDynamics","doc":"- `$select` - Select the fields from `hospital` and `rooms`.\n  - `$where`  - Added the where attribute in the query.","ref":"FatEcto.FatQuery.FatDynamics.html#module-options"},{"type":"function","title":"FatEcto.FatQuery.FatDynamics.array_ilike_dynamic/4","doc":"","ref":"FatEcto.FatQuery.FatDynamics.html#array_ilike_dynamic/4"},{"type":"function","title":"FatEcto.FatQuery.FatDynamics.between_dynamic/4","doc":"Builds a dynamic query where value is between the provided attributes.","ref":"FatEcto.FatQuery.FatDynamics.html#between_dynamic/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatDynamics.between_dynamic/4","doc":"- `key`       - Field name.\n   - `value`     - Values of the field as a list.\n   - `dynamics`  - Default or previous dynamic to append to the query.\n   - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatDynamics.html#between_dynamic/4-parameters"},{"type":"function","title":"Examples - FatEcto.FatQuery.FatDynamics.between_dynamic/4","doc":"iex> result = Elixir.FatEcto.FatQuery.FatDynamics.between_dynamic(\"experience_years\", [2, 5], true, [dynamic_type: :and])\n    iex> inspect(result)\n    \"dynamic([q], q.experience_years > ^2 and q.experience_years < ^5 and ^true)\"","ref":"FatEcto.FatQuery.FatDynamics.html#between_dynamic/4-examples"},{"type":"function","title":"FatEcto.FatQuery.FatDynamics.between_equal_dynamic/4","doc":"Builds a dynamic query where value is equal and between the provided attributes.","ref":"FatEcto.FatQuery.FatDynamics.html#between_equal_dynamic/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatDynamics.between_equal_dynamic/4","doc":"- `key`       - Field name.\n   - `value`     - Values of the field as a list.\n   - `dynamics`  - Default or previous dynamic to append to the query.\n   - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatDynamics.html#between_equal_dynamic/4-parameters"},{"type":"function","title":"Examples - FatEcto.FatQuery.FatDynamics.between_equal_dynamic/4","doc":"iex> result = Elixir.FatEcto.FatQuery.FatDynamics.between_equal_dynamic(\"experience_years\", [2, 5], true, [dynamic_type: :and])\n    iex> inspect(result)\n    \"dynamic([q], q.experience_years >= ^2 and q.experience_years <= ^5 and ^true)\"","ref":"FatEcto.FatQuery.FatDynamics.html#between_equal_dynamic/4-examples"},{"type":"function","title":"FatEcto.FatQuery.FatDynamics.contains_any_dynamic/4","doc":"Builds a dynamic query when value of jsonb matches with any list attribute.","ref":"FatEcto.FatQuery.FatDynamics.html#contains_any_dynamic/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatDynamics.contains_any_dynamic/4","doc":"- `key`       - Field name.\n   - `values`    - values of jsonb field.\n   - `dynamics`  - Default or previous dynamic to append to the query.\n   - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatDynamics.html#contains_any_dynamic/4-parameters"},{"type":"function","title":"FatEcto.FatQuery.FatDynamics.contains_dynamic/4","doc":"Builds a dynamic query when value of jsonb field is in the list.","ref":"FatEcto.FatQuery.FatDynamics.html#contains_dynamic/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatDynamics.contains_dynamic/4","doc":"- `key`       - Field name.\n   - `values`    - values of jsonb field.\n   - `dynamics`  - Default or previous dynamic to append to the query.\n   - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatDynamics.html#contains_dynamic/4-parameters"},{"type":"function","title":"FatEcto.FatQuery.FatDynamics.eq_dynamic/4","doc":"Builds a dynamic query where field is equal to value.","ref":"FatEcto.FatQuery.FatDynamics.html#eq_dynamic/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatDynamics.eq_dynamic/4","doc":"- `key`       - Field name.\n   - `value`     - Value of the field.\n   - `dynamics`  - Default or previous dynamic to append to the query.\n   - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatDynamics.html#eq_dynamic/4-parameters"},{"type":"function","title":"Examples - FatEcto.FatQuery.FatDynamics.eq_dynamic/4","doc":"iex> result = Elixir.FatEcto.FatQuery.FatDynamics.eq_dynamic(\"experience_years\", 2, true, [dynamic_type: :and])\n     iex> inspect(result)\n     \"dynamic([q], q.experience_years == ^2 and ^true)\"","ref":"FatEcto.FatQuery.FatDynamics.html#eq_dynamic/4-examples"},{"type":"function","title":"FatEcto.FatQuery.FatDynamics.gt_dynamic/4","doc":"Builds a dynamic query where field is greater than the value.","ref":"FatEcto.FatQuery.FatDynamics.html#gt_dynamic/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatDynamics.gt_dynamic/4","doc":"- `key`       - Field name.\n   - `value`     - Value of the field.\n   - `dynamics`  - Default or previous dynamic to append to the query.\n   - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatDynamics.html#gt_dynamic/4-parameters"},{"type":"function","title":"Examples - FatEcto.FatQuery.FatDynamics.gt_dynamic/4","doc":"iex> result = Elixir.FatEcto.FatQuery.FatDynamics.gt_dynamic(\"experience_years\", 2, true, [dynamic_type: :or, binding: :last])\n    iex> inspect(result)\n    \"dynamic([_, _, c], c.experience_years > ^2 or ^true)\"","ref":"FatEcto.FatQuery.FatDynamics.html#gt_dynamic/4-examples"},{"type":"function","title":"FatEcto.FatQuery.FatDynamics.gte_dynamic/4","doc":"Builds a dynamic query where field is greater than and equal to given value.","ref":"FatEcto.FatQuery.FatDynamics.html#gte_dynamic/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatDynamics.gte_dynamic/4","doc":"- `key`       - Field name.\n   - `value`     - Value of the field.\n   - `dynamics`  - Default or previous dynamic to append to the query.\n   - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatDynamics.html#gte_dynamic/4-parameters"},{"type":"function","title":"Examples - FatEcto.FatQuery.FatDynamics.gte_dynamic/4","doc":"iex> result = Elixir.FatEcto.FatQuery.FatDynamics.gte_dynamic(\"experience_years\", 2, true, [dynamic_type: :and, binding: :last])\n    iex> inspect(result)\n    \"dynamic([_, _, c], c.experience_years >= ^2 and ^true)\"","ref":"FatEcto.FatQuery.FatDynamics.html#gte_dynamic/4-examples"},{"type":"function","title":"FatEcto.FatQuery.FatDynamics.ilike_dynamic/4","doc":"Builds a dynamic query where field matches the value substring.","ref":"FatEcto.FatQuery.FatDynamics.html#ilike_dynamic/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatDynamics.ilike_dynamic/4","doc":"- `key`       - Field name.\n   - `value`     - Value of the field.\n   - `dynamics`  - Default or previous dynamic to append to the query.\n   - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatDynamics.html#ilike_dynamic/4-parameters"},{"type":"function","title":"FatEcto.FatQuery.FatDynamics.in_dynamic/4","doc":"Builds a dynamic query where value is in the provided list attributes.","ref":"FatEcto.FatQuery.FatDynamics.html#in_dynamic/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatDynamics.in_dynamic/4","doc":"- `key`       - Field name.\n   - `values`    - Pass a list of values of the field that represent range.\n   - `dynamics`  - Default or previous dynamic to append to the query.\n   - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatDynamics.html#in_dynamic/4-parameters"},{"type":"function","title":"Examples - FatEcto.FatQuery.FatDynamics.in_dynamic/4","doc":"iex> result = Elixir.FatEcto.FatQuery.FatDynamics.in_dynamic(\"experience_years\", [2, 5], true, [dynamic_type: :and])\n    iex> inspect(result)\n    \"dynamic([q], q.experience_years in ^[2, 5] and ^true)\"","ref":"FatEcto.FatQuery.FatDynamics.html#in_dynamic/4-examples"},{"type":"function","title":"FatEcto.FatQuery.FatDynamics.like_dynamic/4","doc":"Builds a dynamic query where field matches matches the value substring.","ref":"FatEcto.FatQuery.FatDynamics.html#like_dynamic/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatDynamics.like_dynamic/4","doc":"- `key`       - Field name.\n   - `value`     - Value of the field.\n   - `dynamics`  - Default or previous dynamic to append to the query.\n   - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatDynamics.html#like_dynamic/4-parameters"},{"type":"function","title":"FatEcto.FatQuery.FatDynamics.lt_dynamic/4","doc":"Builds a dynamic query where field is less than the value.","ref":"FatEcto.FatQuery.FatDynamics.html#lt_dynamic/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatDynamics.lt_dynamic/4","doc":"- `key`       - Field name.\n   - `value`     - Value of the field.\n   - `dynamics`  - Default or previous dynamic to append to the query.\n   - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatDynamics.html#lt_dynamic/4-parameters"},{"type":"function","title":"Examples - FatEcto.FatQuery.FatDynamics.lt_dynamic/4","doc":"iex> result = Elixir.FatEcto.FatQuery.FatDynamics.lt_dynamic(\"experience_years\", 2, true, [dynamic_type: :and, binding: :last])\n    iex> inspect(result)\n    \"dynamic([_, _, c], c.experience_years < ^2 and ^true)\"","ref":"FatEcto.FatQuery.FatDynamics.html#lt_dynamic/4-examples"},{"type":"function","title":"FatEcto.FatQuery.FatDynamics.lte_dynamic/4","doc":"Builds a dynamic query where field is less than and equal to the value.","ref":"FatEcto.FatQuery.FatDynamics.html#lte_dynamic/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatDynamics.lte_dynamic/4","doc":"- `key`       - Field name.\n   - `value`     - Value of the field.\n   - `dynamics`  - Default or previous dynamic to append to the query.\n   - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatDynamics.html#lte_dynamic/4-parameters"},{"type":"function","title":"Examples - FatEcto.FatQuery.FatDynamics.lte_dynamic/4","doc":"iex> result = Elixir.FatEcto.FatQuery.FatDynamics.lte_dynamic(\"experience_years\", 2, true, [dynamic_type: :or])\n    iex> inspect(result)\n    \"dynamic([q], q.experience_years <= ^2 or ^true)\"","ref":"FatEcto.FatQuery.FatDynamics.html#lte_dynamic/4-examples"},{"type":"function","title":"FatEcto.FatQuery.FatDynamics.nil_dynamic?/3","doc":"Builds a dynamic query where field is nil.","ref":"FatEcto.FatQuery.FatDynamics.html#nil_dynamic?/3"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatDynamics.nil_dynamic?/3","doc":"- `key`       - Field name .\n  - `dynamics`  - Default or previous dynamic to append to the query.\n  - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatDynamics.html#nil_dynamic?/3-parameters"},{"type":"function","title":"Examples - FatEcto.FatQuery.FatDynamics.nil_dynamic?/3","doc":"iex> result = Elixir.FatEcto.FatQuery.FatDynamics.nil_dynamic?(\"location\", true, [dynamic_type: :and])\n    iex> inspect(result)\n    \"dynamic([c], is_nil(c.location) and ^true)\"","ref":"FatEcto.FatQuery.FatDynamics.html#nil_dynamic?/3-examples"},{"type":"function","title":"FatEcto.FatQuery.FatDynamics.not_eq_dynamic/4","doc":"","ref":"FatEcto.FatQuery.FatDynamics.html#not_eq_dynamic/4"},{"type":"module","title":"FatEcto.FatQuery.FatNotDynamics","doc":"Builds a `where query` using dynamics and not condition.","ref":"FatEcto.FatQuery.FatNotDynamics.html"},{"type":"module","title":"Parameters - FatEcto.FatQuery.FatNotDynamics","doc":"- `queryable`   - Ecto Queryable that represents your schema name, table name or query.\n  - `query_opts`  - Where query options as a map.","ref":"FatEcto.FatQuery.FatNotDynamics.html#module-parameters"},{"type":"module","title":"Examples - FatEcto.FatQuery.FatNotDynamics","doc":"iex> query_opts = %{\n    ...>    \"$select\" => %{\n    ...>     \"$fields\" => [\"name\", \"location\", \"rating\"]\n    ...>    },\n    ...>   \"$where\" => %{\n    ...>      \"name\" => \"%John%\",\n    ...>      \"location\" => nil,\n    ...>      \"rating\" => \"$not_null\",\n    ...>      \"total_staff\" => %{\"$between\" => [1, 3]}\n    ...>    }\n    ...>  }\n    iex> Elixir.MyApp.Query.build!(FatEcto.FatHospital, query_opts)\n    #Ecto.Query  ^1 and f0.total_staff < ^3 and\n  (not is_nil(f0.rating) and (f0.name == ^\"%John%\" and (is_nil(f0.location) and ^true))), select: map(f0, [:name, :location, :rating])>","ref":"FatEcto.FatQuery.FatNotDynamics.html#module-examples"},{"type":"module","title":"Options - FatEcto.FatQuery.FatNotDynamics","doc":"- `$select` - Select the fields from `hospital` and `rooms`.\n  - `$where`  - Added the where attribute in the query.","ref":"FatEcto.FatQuery.FatNotDynamics.html#module-options"},{"type":"function","title":"FatEcto.FatQuery.FatNotDynamics.eq_dynamic/4","doc":"Builds a dynamic query where field is equal to the value.","ref":"FatEcto.FatQuery.FatNotDynamics.html#eq_dynamic/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatNotDynamics.eq_dynamic/4","doc":"- `key`       - Field name.\n   - `value`     - Value of the field.\n   - `dynamics`  - Default or previous dynamic to append to the query.\n   - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatNotDynamics.html#eq_dynamic/4-parameters"},{"type":"function","title":"Examples - FatEcto.FatQuery.FatNotDynamics.eq_dynamic/4","doc":"iex> result = Elixir.FatEcto.FatQuery.FatNotDynamics.eq_dynamic(\"experience_years\", 2, true, [dynamic_type: :and])\n     iex> inspect(result)\n     \"dynamic([q], q.experience_years == ^2 and ^true)\"","ref":"FatEcto.FatQuery.FatNotDynamics.html#eq_dynamic/4-examples"},{"type":"function","title":"FatEcto.FatQuery.FatNotDynamics.not_between_dynamic/4","doc":"Builds a dynamic query where value is not between the provided attributes.","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_between_dynamic/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatNotDynamics.not_between_dynamic/4","doc":"- `key`       - Field name.\n   - `value`     - Values of the field as a list.\n   - `dynamics`  - Default or previous dynamic to append to the query.\n   - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_between_dynamic/4-parameters"},{"type":"function","title":"Examples - FatEcto.FatQuery.FatNotDynamics.not_between_dynamic/4","doc":"iex> result = Elixir.FatEcto.FatQuery.FatNotDynamics.not_between_dynamic(\"experience_years\", [2, 5], true, [dynamic_type: :and])\n    iex> inspect(result)\n    \"dynamic([q], (q.experience_years < ^2 or q.experience_years > ^5) and ^true)\"","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_between_dynamic/4-examples"},{"type":"function","title":"FatEcto.FatQuery.FatNotDynamics.not_between_equal_dynamic/4","doc":"Builds a dynamic query where value is not equal and between the provided attributes.","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_between_equal_dynamic/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatNotDynamics.not_between_equal_dynamic/4","doc":"- `key`       - Field name.\n   - `value`     - Values of the field as a list.\n   - `dynamics`  - Default or previous dynamic to append to the query.\n   - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_between_equal_dynamic/4-parameters"},{"type":"function","title":"Examples - FatEcto.FatQuery.FatNotDynamics.not_between_equal_dynamic/4","doc":"iex> result = Elixir.FatEcto.FatQuery.FatNotDynamics.not_between_equal_dynamic(\"experience_years\", [2, 5], true, [dynamic_type: :and])\n    iex> inspect(result)\n    \"dynamic([q], (q.experience_years <= ^2 or q.experience_years >= ^5) and ^true)\"","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_between_equal_dynamic/4-examples"},{"type":"function","title":"FatEcto.FatQuery.FatNotDynamics.not_contains_any_dynamic/4","doc":"Builds a dynamic query when value of jsonb not matches with any list attribute.","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_contains_any_dynamic/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatNotDynamics.not_contains_any_dynamic/4","doc":"- `key`       - Field name.\n   - `values`    - values of jsonb field.\n   - `dynamics`  - Default or previous dynamic to append to the query.\n   - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_contains_any_dynamic/4-parameters"},{"type":"function","title":"FatEcto.FatQuery.FatNotDynamics.not_contains_dynamic/4","doc":"Builds a dynamic query when value of jsonb field is not in the list.","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_contains_dynamic/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatNotDynamics.not_contains_dynamic/4","doc":"- `key`       - Field name.\n   - `values`    - values of jsonb field.\n   - `dynamics`  - Default or previous dynamic to append to the query.\n   - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_contains_dynamic/4-parameters"},{"type":"function","title":"FatEcto.FatQuery.FatNotDynamics.not_eq_dynamic/4","doc":"Builds a dynamic query where field is not equal to the value.","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_eq_dynamic/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatNotDynamics.not_eq_dynamic/4","doc":"- `key`       - Field name.\n   - `value`     - Value of the field.\n   - `dynamics`  - Default or previous dynamic to append to the query.\n   - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_eq_dynamic/4-parameters"},{"type":"function","title":"Examples - FatEcto.FatQuery.FatNotDynamics.not_eq_dynamic/4","doc":"iex> result = Elixir.FatEcto.FatQuery.FatNotDynamics.not_eq_dynamic(\"experience_years\", 2, true, [dynamic_type: :and])\n     iex> inspect(result)\n     \"dynamic([q], q.experience_years != ^2 and ^true)\"","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_eq_dynamic/4-examples"},{"type":"function","title":"FatEcto.FatQuery.FatNotDynamics.not_gt_dynamic/4","doc":"Builds a dynamic query where field is not greater than the value.","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_gt_dynamic/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatNotDynamics.not_gt_dynamic/4","doc":"- `key`       - Field name.\n   - `value`     - Value of the field.\n   - `dynamics`  - Default or previous dynamic to append to the query.\n   - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_gt_dynamic/4-parameters"},{"type":"function","title":"Examples - FatEcto.FatQuery.FatNotDynamics.not_gt_dynamic/4","doc":"iex> result = Elixir.FatEcto.FatQuery.FatNotDynamics.not_gt_dynamic(\"experience_years\", 2, true, [dynamic_type: :or, binding: :last])\n    iex> inspect(result)\n    \"dynamic([_, _, c], c.experience_years < ^2 or ^true)\"","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_gt_dynamic/4-examples"},{"type":"function","title":"FatEcto.FatQuery.FatNotDynamics.not_gte_dynamic/4","doc":"Builds a dynamic query where field is not greater than or equal to the value.","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_gte_dynamic/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatNotDynamics.not_gte_dynamic/4","doc":"- `key`       - Field name.\n   - `value`     - Value of the field.\n   - `dynamics`  - Default or previous dynamic to append to the query.\n   - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_gte_dynamic/4-parameters"},{"type":"function","title":"Examples - FatEcto.FatQuery.FatNotDynamics.not_gte_dynamic/4","doc":"iex> result = Elixir.FatEcto.FatQuery.FatNotDynamics.not_gte_dynamic(\"experience_years\", 2, true, [dynamic_type: :and, binding: :last])\n    iex> inspect(result)\n    \"dynamic([_, _, c], c.experience_years < ^2 and ^true)\"","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_gte_dynamic/4-examples"},{"type":"function","title":"FatEcto.FatQuery.FatNotDynamics.not_ilike_dynamic/4","doc":"Builds a dynamic query where field not matches the value substring.","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_ilike_dynamic/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatNotDynamics.not_ilike_dynamic/4","doc":"- `key`       - Field name.\n   - `value`     - Value of the field.\n   - `dynamics`  - Default or previous dynamic to append to the query.\n   - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_ilike_dynamic/4-parameters"},{"type":"function","title":"FatEcto.FatQuery.FatNotDynamics.not_in_dynamic/4","doc":"Builds a dynamic query where value is not in the the list attributes.","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_in_dynamic/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatNotDynamics.not_in_dynamic/4","doc":"- `key`       - Field name.\n   - `values`    - Pass a list of values of the field that represent range.\n   - `dynamics`  - Default or previous dynamic to append to the query.\n   - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_in_dynamic/4-parameters"},{"type":"function","title":"Examples - FatEcto.FatQuery.FatNotDynamics.not_in_dynamic/4","doc":"iex> result = Elixir.FatEcto.FatQuery.FatNotDynamics.not_in_dynamic(\"experience_years\", [2, 5], true, [dynamic_type: :and])\n    iex> inspect(result)\n    \"dynamic([q], q.experience_years not in ^[2, 5] and ^true)\"","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_in_dynamic/4-examples"},{"type":"function","title":"FatEcto.FatQuery.FatNotDynamics.not_like_dynamic/4","doc":"Builds a dynamic query where field not matches the value substring.","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_like_dynamic/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatNotDynamics.not_like_dynamic/4","doc":"- `key`       - Field name.\n   - `value`     - Value of the field.\n   - `dynamics`  - Default or previous dynamic to append to the query.\n   - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_like_dynamic/4-parameters"},{"type":"function","title":"FatEcto.FatQuery.FatNotDynamics.not_lt_dynamic/4","doc":"Builds a dynamic query where field is not less than the value.","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_lt_dynamic/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatNotDynamics.not_lt_dynamic/4","doc":"- `key`       - Field name.\n   - `value`     - Value of the field.\n   - `dynamics`  - Default or previous dynamic to append to the query.\n   - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_lt_dynamic/4-parameters"},{"type":"function","title":"Examples - FatEcto.FatQuery.FatNotDynamics.not_lt_dynamic/4","doc":"iex> result = Elixir.FatEcto.FatQuery.FatNotDynamics.not_lt_dynamic(\"experience_years\", 2, true, [dynamic_type: :and, binding: :last])\n    iex> inspect(result)\n    \"dynamic([_, _, c], c.experience_years > ^2 and ^true)\"","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_lt_dynamic/4-examples"},{"type":"function","title":"FatEcto.FatQuery.FatNotDynamics.not_lte_dynamic/4","doc":"Builds a dynamic query where field is not less than or equal to the value.","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_lte_dynamic/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatNotDynamics.not_lte_dynamic/4","doc":"- `key`       - Field name.\n   - `value`     - Value of the field.\n   - `dynamics`  - Default or previous dynamic to append to the query.\n   - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_lte_dynamic/4-parameters"},{"type":"function","title":"Examples - FatEcto.FatQuery.FatNotDynamics.not_lte_dynamic/4","doc":"iex> result = Elixir.FatEcto.FatQuery.FatNotDynamics.not_lte_dynamic(\"experience_years\", 2, true, [dynamic_type: :and, binding: :last])\n    iex> inspect(result)\n    \"dynamic([c], c.experience_years > ^2 and ^true)\"","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_lte_dynamic/4-examples"},{"type":"function","title":"FatEcto.FatQuery.FatNotDynamics.not_nil_dynamic?/3","doc":"Builds a dynamic query where field is not nil.","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_nil_dynamic?/3"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatNotDynamics.not_nil_dynamic?/3","doc":"- `key`       - Field name .\n  - `dynamics`  - Default or previous dynamic to append to the query.\n  - `opts`      - Options related to query bindings alongwith dynamic type(and/or).","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_nil_dynamic?/3-parameters"},{"type":"function","title":"Examples - FatEcto.FatQuery.FatNotDynamics.not_nil_dynamic?/3","doc":"iex> result = Elixir.FatEcto.FatQuery.FatNotDynamics.not_nil_dynamic?(\"location\", true, [dynamic_type: :and])\n    iex> inspect(result)\n    \"dynamic([c], not is_nil(c.location) and ^true)\"","ref":"FatEcto.FatQuery.FatNotDynamics.html#not_nil_dynamic?/3-examples"},{"type":"module","title":"FatEcto.FatQuery.FatOrderBy","doc":"Builds query with `asc` or `desc` order.\n\nThis module provides functionality to dynamically add `order_by` clauses to Ecto queries\nbased on the provided parameters. It supports various order formats, including `$asc`,\n`$desc`, and nulls handling (`$asc_nulls_first`, `$desc_nulls_last`, etc.).","ref":"FatEcto.FatQuery.FatOrderBy.html"},{"type":"function","title":"FatEcto.FatQuery.FatOrderBy.build_order_by/4","doc":"Orders the results based on the `order_by` clause in the params.","ref":"FatEcto.FatQuery.FatOrderBy.html#build_order_by/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatOrderBy.build_order_by/4","doc":"- `queryable`: Ecto Queryable that represents your schema name, table name, or query.\n  - `order_by_params`: A map of fields and their order formats (e.g., `%{\"field\" => \"$asc\"}`).\n  - `opts`: Options related to query bindings.\n  - `build_options`: Options related to the OTP app (unused in this function).","ref":"FatEcto.FatQuery.FatOrderBy.html#build_order_by/4-parameters"},{"type":"function","title":"Examples - FatEcto.FatQuery.FatOrderBy.build_order_by/4","doc":"iex> query_opts = %{\"$order\" => %{\"id\" => \"$asc\"}}\n    iex> FatEcto.FatQuery.FatOrderBy.build_order_by(FatEcto.FatHospital, query_opts[\"$order\"], [], [])\n    #Ecto.Query","ref":"FatEcto.FatQuery.FatOrderBy.html#build_order_by/4-examples"},{"type":"module","title":"FatEcto.FatQuery.FatWhere","doc":"Where supports multiple query methods.\n\n## => like","ref":"FatEcto.FatQuery.FatWhere.html"},{"type":"module","title":"Parameters - FatEcto.FatQuery.FatWhere","doc":"- `queryable`   - Ecto Queryable that represents your schema name, table name or query.\n- `query_opts`  - Include query options as a map.","ref":"FatEcto.FatQuery.FatWhere.html#module-parameters"},{"type":"module","title":"Example - FatEcto.FatQuery.FatWhere","doc":"iex> query_opts = %{\n  ...>   \"$select\" => %{\"$fields\" => [\"phone\", \"designation\", \"experience_years\"]},\n  ...>   \"$where\" => %{\"designation\" => %{\"$like\" => \"%Joh %\"}}\n  ...> }\n  iex> Elixir.MyApp.Query.build!(FatEcto.FatDoctor, query_opts)\n  #Ecto.Query","ref":"FatEcto.FatQuery.FatWhere.html#module-example"},{"type":"module","title":"Options - FatEcto.FatQuery.FatWhere","doc":"- `$select`- Select the fields from `doctor`.\n- `$like`- Added the like attribute in the where query.\n\n## => iLike","ref":"FatEcto.FatQuery.FatWhere.html#module-options"},{"type":"module","title":"Parameters - FatEcto.FatQuery.FatWhere","doc":"- `queryable`   - Ecto Queryable that represents your schema name, table name or query.\n- `query_opts`  - Include query options as a map","ref":"FatEcto.FatQuery.FatWhere.html#module-parameters"},{"type":"module","title":"Example - FatEcto.FatQuery.FatWhere","doc":"iex> query_opts = %{\n  ...>   \"$select\" => %{\"$fields\" => [\"phone\", \"designation\", \"experience_years\"]},\n  ...>   \"$where\" => %{\"designation\" => %{\"$ilike\" => \"%surge %\"}},\n  ...>   \"$order\" => %{\"rating\" => \"$asc\"}\n  ...> }\n  iex> Elixir.MyApp.Query.build!(FatEcto.FatDoctor, query_opts)\n  #Ecto.Query","ref":"FatEcto.FatQuery.FatWhere.html#module-example"},{"type":"module","title":"Options - FatEcto.FatQuery.FatWhere","doc":"- `$select`- Select the fields from `doctor`.\n- `$ilike`- Added the ilike attribute in the where query.\n- `$order`- Sort the result based on the order attribute.\n\n\n\n## => notLike","ref":"FatEcto.FatQuery.FatWhere.html#module-options"},{"type":"module","title":"Parameters - FatEcto.FatQuery.FatWhere","doc":"- `queryable`   - Ecto Queryable that represents your schema name, table name or query.\n- `query_opts`  - Include query options as a map","ref":"FatEcto.FatQuery.FatWhere.html#module-parameters"},{"type":"module","title":"Example - FatEcto.FatQuery.FatWhere","doc":"iex> query_opts = %{\n  ...>  \"$select\" => %{\n  ...>    \"$fields\" => [\"name\", \"location\", \"rating\"],\n  ...>    \"fat_rooms\" => [\"name\", \"floor\"],\n  ...>   },\n  ...>  \"$where\" => %{\"location\" => %{\"$not_like\" => \"%street2 %\"}},\n  ...>  \"$order\" => %{\"id\" => \"$desc\"}\n  ...> }\n  iex> Elixir.MyApp.Query.build!(FatEcto.FatHospital, query_opts)\n  #Ecto.Query","ref":"FatEcto.FatQuery.FatWhere.html#module-example"},{"type":"module","title":"Options - FatEcto.FatQuery.FatWhere","doc":"- `$select`- Select the fields from `hospital` and `rooms`.\n- `$not_like`- Added the notlike attribute in the where query.\n- `$order`- Sort the result based on the order attribute.\n\n\n\n## => notILike","ref":"FatEcto.FatQuery.FatWhere.html#module-options"},{"type":"module","title":"Parameters - FatEcto.FatQuery.FatWhere","doc":"- `queryable`   - Ecto Queryable that represents your schema name, table name or query.\n- `query_opts`  - Include query options as a map","ref":"FatEcto.FatQuery.FatWhere.html#module-parameters"},{"type":"module","title":"Example - FatEcto.FatQuery.FatWhere","doc":"iex> query_opts = %{\n  ...>  \"$select\" => %{\n  ...>    \"$fields\" => [\"name\", \"location\", \"rating\"]\n  ...>   },\n  ...>  \"$where\" => %{\"location\" => %{\"$not_ilike\" => \"%street2 %\"}},\n  ...>  \"$group\" => \"rating\"\n  ...> }\n  iex> Elixir.MyApp.Query.build!(FatEcto.FatHospital, query_opts)\n  #Ecto.Query","ref":"FatEcto.FatQuery.FatWhere.html#module-example"},{"type":"module","title":"Options - FatEcto.FatQuery.FatWhere","doc":"- `$select`- Select the fields from `hospital` and `rooms`.\n- `$not_ilike`- Added the notilike attribute in the where query.\n- `$group`- Added the group_by attribute in the query.\n\n\n\n\n## => lessThan","ref":"FatEcto.FatQuery.FatWhere.html#module-options"},{"type":"module","title":"Parameters - FatEcto.FatQuery.FatWhere","doc":"- `queryable`   - Ecto Queryable that represents your schema name, table name or query.\n- `query_opts`  - Include query options as a map","ref":"FatEcto.FatQuery.FatWhere.html#module-parameters"},{"type":"module","title":"Example - FatEcto.FatQuery.FatWhere","doc":"iex> query_opts = %{\n  ...>    \"$select\" => %{\n  ...>     \"$fields\" => [\"name\", \"location\", \"rating\"]\n  ...>    },\n  ...>   \"$where\" => %{\"rating\" => %{\"$lt\" => 4}}\n  ...>  }\n  iex> Elixir.MyApp.Query.build!(FatEcto.FatHospital, query_opts)\n  #Ecto.Query","ref":"FatEcto.FatQuery.FatWhere.html#module-example"},{"type":"module","title":"Options - FatEcto.FatQuery.FatWhere","doc":"- `$select`- Select the fields from `hospital`.\n- `$lt`- Added the lessthan attribute in the where query.\n\n\n\n\n## => lessThan the other field","ref":"FatEcto.FatQuery.FatWhere.html#module-options"},{"type":"module","title":"Parameters - FatEcto.FatQuery.FatWhere","doc":"- `queryable`   - Ecto Queryable that represents your schema name, table name or query.\n- `query_opts`  - Include query options as a map","ref":"FatEcto.FatQuery.FatWhere.html#module-parameters"},{"type":"module","title":"Example - FatEcto.FatQuery.FatWhere","doc":"iex> query_opts = %{\n  ...>   \"$select\" => %{\n  ...>      \"$fields\" => [\"name\", \"location\", \"rating\"]\n  ...>    },\n  ...>    \"$where\" => %{\"total_staff\" => %{\"$lt\" => \"$rating\"}},\n  ...>    \"$order\" => %{\"id\" => \"$desc\"}\n  ...>  }\n  iex> Elixir.MyApp.Query.build!(FatEcto.FatHospital, query_opts)\n  #Ecto.Query","ref":"FatEcto.FatQuery.FatWhere.html#module-example"},{"type":"module","title":"Options - FatEcto.FatQuery.FatWhere","doc":"- `$select`- Select the fields from `hospital`.\n- `$lt: :$field`- Added the lessthan attribute in the where query.\n- `$order`- Sort the result based on the order attribute.\n\n\n\n\n## => lessThanEqual","ref":"FatEcto.FatQuery.FatWhere.html#module-options"},{"type":"module","title":"Parameters - FatEcto.FatQuery.FatWhere","doc":"- `queryable`   - Ecto Queryable that represents your schema name, table name or query.\n- `query_opts`  - Include query options as a map","ref":"FatEcto.FatQuery.FatWhere.html#module-parameters"},{"type":"module","title":"Example - FatEcto.FatQuery.FatWhere","doc":"iex> query_opts = %{\n  ...>   \"$select\" => %{\n  ...>     \"$fields\" => [\"name\", \"location\", \"rating\"],\n  ...>     \"fat_rooms\" => [\"name\", \"floor\"]\n  ...>    },\n  ...>   \"$where\" => %{\"total_staff\" => %{\"$lte\" => 3}},\n  ...>  }\n  iex> Elixir.MyApp.Query.build!(FatEcto.FatHospital, query_opts)\n  #Ecto.Query","ref":"FatEcto.FatQuery.FatWhere.html#module-example"},{"type":"module","title":"Options - FatEcto.FatQuery.FatWhere","doc":"- `$select`- Select the fields from `hospital` and `rooms`.\n- `$lte`- Added the lessthanequal attribute in the where query.\n\n\n\n## => lessThanEqual the other field","ref":"FatEcto.FatQuery.FatWhere.html#module-options"},{"type":"module","title":"Parameters - FatEcto.FatQuery.FatWhere","doc":"- `queryable`   - Ecto Queryable that represents your schema name, table name or query.\n- `query_opts`  - Include query options as a map","ref":"FatEcto.FatQuery.FatWhere.html#module-parameters"},{"type":"module","title":"Example - FatEcto.FatQuery.FatWhere","doc":"iex> query_opts = %{\n  ...>  \"$select\" => %{\n  ...>    \"$fields\" => [\"name\", \"location\", \"rating\"],\n  ...>    \"fat_rooms\" => [\"name\", \"floor\"]\n  ...>   },\n  ...>  \"$where\" => %{\"total_staff\" => %{\"$lte\" => \"$rating\"}},\n  ...>  \"$group\" => \"total_staff\"\n  ...> }\n  iex> Elixir.MyApp.Query.build!(FatEcto.FatHospital, query_opts)\n  #Ecto.Query","ref":"FatEcto.FatQuery.FatWhere.html#module-example"},{"type":"module","title":"Options - FatEcto.FatQuery.FatWhere","doc":"- `$select`- Select the fields from `hospital` and `rooms`.\n- `$lte: :$field`- Added the lessthanequal attribute in the where query.\n- `$group`- Added the group_by attribute in the query.\n\n\n\n## => greaterThan","ref":"FatEcto.FatQuery.FatWhere.html#module-options"},{"type":"module","title":"Parameters - FatEcto.FatQuery.FatWhere","doc":"- `queryable`   - Ecto Queryable that represents your schema name, table name or query.\n- `query_opts`  - Include query options as a map","ref":"FatEcto.FatQuery.FatWhere.html#module-parameters"},{"type":"module","title":"Example - FatEcto.FatQuery.FatWhere","doc":"iex> query_opts = %{\n  ...>  \"$select\" => %{\n  ...>   \"$fields\" => [\"name\", \"location\", \"rating\"],\n  ...>   \"fat_rooms\" => [\"name\", \"floor\"]\n  ...>  },\n  ...>  \"$where\" => %{\"total_staff\" => %{\"$gt\" => 4}},\n  ...>  \"$group\" => \"total_staff\",\n  ...>  \"$order\" => %{\"rating\" => \"$desc\"}\n  ...> }\n  iex> Elixir.MyApp.Query.build!(FatEcto.FatHospital, query_opts)\n  #Ecto.Query  ^4 and ^true, group_by: [f0.total_staff], order_by: [desc: f0.rating], select: map(f0, [:name, :location, :rating, fat_rooms: [:name, :floor]])>","ref":"FatEcto.FatQuery.FatWhere.html#module-example"},{"type":"module","title":"Options - FatEcto.FatQuery.FatWhere","doc":"- `$select`- Select the fields from `hospital` and `rooms`.\n- `$gt`- Added the lessthan attribute in the where query.\n- `$group`- Added the group_by attribute in the query.\n- `$order`- Sort the result based on the order attribute.\n\n\n\n\n## => greaterThan the other field","ref":"FatEcto.FatQuery.FatWhere.html#module-options"},{"type":"module","title":"Parameters - FatEcto.FatQuery.FatWhere","doc":"- `queryable`   - Ecto Queryable that represents your schema name, table name or query.\n- `query_opts`  - Include query options as a map","ref":"FatEcto.FatQuery.FatWhere.html#module-parameters"},{"type":"module","title":"Example - FatEcto.FatQuery.FatWhere","doc":"iex> query_opts = %{\n  ...>  \"$select\" => %{\n  ...>   \"$fields\" => [\"name\", \"location\", \"rating\"],\n  ...>   \"fat_rooms\" => [\"name\", \"floor\"]\n  ...>  },\n  ...>  \"$where\" => %{\"total_staff\" => %{\"$gt\" => \"$rating\"}},\n  ...>  \"$include\" => %{\n  ...>    \"fat_doctors\" => %{\n  ...>      \"$where\" => %{\"rating\" => %{\"$lt\" => 3}},\n  ...>      \"$order\" => %{\"id\" => \"$desc\"}\n  ...>    }\n  ...>   }\n  ...> }\n  iex> Elixir.MyApp.Query.build!(FatEcto.FatHospital, query_opts)\n  #Ecto.Query  f0.rating and ^true, where: f1.rating < ^3 and ^true, order_by: [desc: f1.id], limit: ^34, offset: ^0, select: map(f0, [:name, :location, :rating, fat_rooms: [:name, :floor]]), preload: [:fat_doctors]>","ref":"FatEcto.FatQuery.FatWhere.html#module-example"},{"type":"module","title":"Options - FatEcto.FatQuery.FatWhere","doc":"- `$select`- Select the fields from `hospital`.\n- `$gt: :$field`- Added the greaterthan attribute in the where query.\n- `$include`- Include the assoication model `doctors`.\n- `$lt`- Added the lessthan attribute in the where query inside include.\n\n\n\n## => greaterThanEqual","ref":"FatEcto.FatQuery.FatWhere.html#module-options"},{"type":"module","title":"Parameters - FatEcto.FatQuery.FatWhere","doc":"- `queryable`   - Ecto Queryable that represents your schema name, table name or query.\n- `query_opts`  - Include query options as a map","ref":"FatEcto.FatQuery.FatWhere.html#module-parameters"},{"type":"module","title":"Example - FatEcto.FatQuery.FatWhere","doc":"iex> query_opts = %{\n  ...>  \"$select\" => %{\n  ...>   \"$fields\" => [\"name\", \"location\", \"rating\"],\n  ...>   \"fat_rooms\" => [\"name\", \"floor\"]\n  ...>  },\n  ...>  \"$where\" => %{\"total_staff\" => %{\"$gte\" => 5}},\n  ...>  \"$include\" => %{\n  ...>   \"fat_doctors\" => %{\n  ...>    \"$where\" => %{\"rating\" => %{\"$lte\" => 3}},\n  ...>   }\n  ...>  }\n  ...> }\n  iex> Elixir.MyApp.Query.build!(FatEcto.FatHospital, query_opts)\n  #Ecto.Query = ^5 and ^true, where: f0.rating <= ^3 and ^true, limit: ^34, offset: ^0, select: map(f0, [:name, :location, :rating, fat_rooms: [:name, :floor]]), preload: [:fat_doctors]>","ref":"FatEcto.FatQuery.FatWhere.html#module-example"},{"type":"module","title":"Options - FatEcto.FatQuery.FatWhere","doc":"- `$select`- Select the fields from `hospital` and `rooms`.\n- `$gte`- Added the greaterthanequal attribute in the where query.\n- `$include`- Include the assoication model `doctors`.\n- `$lte`- Added the lessthanequal attribute in the where query inside include.\n\n\n\n\n\n## => greaterThanEqual the other field","ref":"FatEcto.FatQuery.FatWhere.html#module-options"},{"type":"module","title":"Parameters - FatEcto.FatQuery.FatWhere","doc":"- `queryable`   - Ecto Queryable that represents your schema name, table name or query.\n- `query_opts`  - Include query options as a map","ref":"FatEcto.FatQuery.FatWhere.html#module-parameters"},{"type":"module","title":"Example - FatEcto.FatQuery.FatWhere","doc":"iex> query_opts = %{\n  ...>  \"$select\" => %{\n  ...>    \"$fields\" => [\"name\", \"location\", \"rating\"],\n  ...>    \"fat_rooms\" => [\"name\", \"floor\"]\n  ...>   },\n  ...>  \"$where\" => %{\"rating\" => %{\"$gte\" => \"$total_staff\"}},\n  ...>  \"$include\" => %{\n  ...>    \"fat_doctors\" => %{\n  ...>      \"$where\" => %{\"rating\" => %{\"$gte\" => 3}},\n  ...>      \"$order\" => %{\"rating\" => \"$asc\"}\n  ...>     }\n  ...>   }\n  ...> }\n  iex> Elixir.MyApp.Query.build!(FatEcto.FatHospital, query_opts)\n  #Ecto.Query = f0.total_staff and ^true, where: f1.rating >= ^3 and ^true, order_by: [asc: f1.rating], limit: ^34, offset: ^0, select: map(f0, [:name, :location, :rating, fat_rooms: [:name, :floor]]), preload: [:fat_doctors]>","ref":"FatEcto.FatQuery.FatWhere.html#module-example"},{"type":"module","title":"Options - FatEcto.FatQuery.FatWhere","doc":"- `$select`- Select the fields from `hospital` and `rooms`.\n- `$gte: :$field`- Added the  greaterthanequal attribute in the where query.\n- `$include`- Include the assoication model `doctors`.\n- `$gte`- Added the greaterthanequal attribute in the where query inside include.\n- `$order`- Sort the result based on the order attribute.\n\n\n## => between","ref":"FatEcto.FatQuery.FatWhere.html#module-options"},{"type":"module","title":"Parameters - FatEcto.FatQuery.FatWhere","doc":"- `queryable`   - Ecto Queryable that represents your schema name, table name or query.\n- `query_opts`  - Include query options as a map","ref":"FatEcto.FatQuery.FatWhere.html#module-parameters"},{"type":"module","title":"Example - FatEcto.FatQuery.FatWhere","doc":"iex> query_opts = %{\n  ...>  \"$select\" => %{\n  ...>   \"$fields\" => [\"name\", \"location\", \"rating\"],\n  ...>   \"fat_rooms\" => [\"name\", \"floor\"]\n  ...>  },\n  ...>  \"$where\" => %{\"rating\" => %{\"$between\" => [10, 20]}},\n  ...>  \"$include\" => %{\n  ...>    \"fat_doctors\" => %{\n  ...>      \"$include\" => [\"fat_patients\"],\n  ...>      \"$where\" => %{\"rating\" => %{\"$gte\" => \"$total_staff\"}},\n  ...>      \"$order\" => %{\"rating\" => \"$asc\"}\n  ...>    }\n  ...>   }\n  ...> }\n  iex> Elixir.MyApp.Query.build!(FatEcto.FatHospital, query_opts)\n  #Ecto.Query  ^10 and f0.rating < ^20 and ^true, where: f1.rating >= f1.total_staff and ^true, order_by: [asc: f1.rating], limit: ^34, offset: ^0, select: map(f0, [:name, :location, :rating, {:fat_rooms, [:name, :floor]}]), preload: [[fat_doctors: [:fat_patients]]]>","ref":"FatEcto.FatQuery.FatWhere.html#module-example"},{"type":"module","title":"Options - FatEcto.FatQuery.FatWhere","doc":"- `$select`- Select the fields from `hospital` and `rooms`.\n- `$between: :$field`- Added the  between attribute in the where query.\n- `$include`- Include the assoication model `doctors` and `patients`.\n- `$gte`- Added the greaterthanequal attribute in the where query inside include.\n- `$order`- Sort the result based on the order attribute.\n\n## => not_between","ref":"FatEcto.FatQuery.FatWhere.html#module-options"},{"type":"module","title":"Parameters - FatEcto.FatQuery.FatWhere","doc":"- `queryable`   - Ecto Queryable that represents your schema name, table name or query.\n- `query_opts`  - Include query options as a map","ref":"FatEcto.FatQuery.FatWhere.html#module-parameters"},{"type":"module","title":"Example - FatEcto.FatQuery.FatWhere","doc":"iex> query_opts = %{\n  ...> \"$select\" => %{\n  ...>   \"$fields\" => [\"name\", \"location\", \"rating\"],\n  ...>   \"fat_rooms\" => [\"name\", \"floor\"]\n  ...>   },\n  ...>  \"$where\" => %{\"rating\" => %{\"$not_between\" => [10, 20]}},\n  ...>  \"$include\" => %{\n  ...>    \"fat_doctors\" => %{\n  ...>      \"$include\" => [\"fat_patients\"],\n  ...>      \"$where\" => %{\"rating\" => %{\"$between\" => [20, 30]}},\n  ...>      \"$order\" => %{\"experience_years\" => \"$asc\"}\n  ...>    }\n  ...>   }\n  ...>  }\n  iex> Elixir.MyApp.Query.build!(FatEcto.FatHospital, query_opts)\n  #Ecto.Query  ^20) and ^true, where: f1.rating > ^20 and f1.rating < ^30 and ^true, order_by: [asc: f1.experience_years], limit: ^34, offset: ^0, select: map(f0, [:name, :location, :rating, {:fat_rooms, [:name, :floor]}]), preload: [[fat_doctors: [:fat_patients]]]>","ref":"FatEcto.FatQuery.FatWhere.html#module-example"},{"type":"module","title":"Options - FatEcto.FatQuery.FatWhere","doc":"- `$select`- Select the fields from `hospital` and `rooms`.\n- `$not_between: :$field`- Added the  notbetween attribute in the where query.\n- `$include`- Include the assoication model `doctors` and `patients`.\n- `$between`- Added the between attribute in the where query inside include.\n- `$order`- Sort the result based on the order attribute.\n\n\n\n## => in","ref":"FatEcto.FatQuery.FatWhere.html#module-options"},{"type":"module","title":"Parameters - FatEcto.FatQuery.FatWhere","doc":"- `queryable`   - Ecto Queryable that represents your schema name, table name or query.\n- `query_opts`  - Include query options as a map","ref":"FatEcto.FatQuery.FatWhere.html#module-parameters"},{"type":"module","title":"Example - FatEcto.FatQuery.FatWhere","doc":"iex> query_opts = %{\n  ...>   \"$select\" => %{\n  ...>    \"$fields\" => [\"name\", \"location\", \"rating\"],\n  ...>    \"fat_rooms\" => [\"name\", \"floor\"]\n  ...>   },\n  ...>   \"$where\" => %{\"rating\" => %{\"$in\" => [10, 20]}},\n  ...>   \"$include\" => %{\n  ...>     \"fat_doctors\" => %{\n  ...>      \"$include\" => [\"fat_patients\"],\n  ...>      \"$where\" => %{\"rating\" => %{\"$not_between\" => [20, 30]}},\n  ...>      \"$order\" => %{\"experience_years\" => \"$asc\"}\n  ...>     }\n  ...>    },\n  ...>    \"$right_join\" => %{\n  ...>     \"fat_rooms\" => %{\n  ...>      \"$on_field\" => \"id\",\n  ...>      \"$on_table_field\" => \"hospital_id\",\n  ...>      \"$select\" => [\"name\", \"purpose\", \"floor\"],\n  ...>      \"$where\" => %{\"floor\" => %{\"$gte\" => 2}}\n  ...>    }\n  ...>   }\n  ...>  }\n  iex> Elixir.MyApp.Query.build!(FatEcto.FatHospital, query_opts)\n  #Ecto.Query = ^2 and ^true, where: (f2.rating < ^20 or f2.rating > ^30) and ^true, order_by: [asc: f2.experience_years], limit: ^34, offset: ^0, select: merge(map(f0, [:name, :location, :rating, fat_rooms: [:name, :floor]]), %{\n  ^\"fat_rooms\" => map(f1, [:name, :purpose, :floor])\n}), preload: [fat_doctors: [:fat_patients]]>","ref":"FatEcto.FatQuery.FatWhere.html#module-example"},{"type":"module","title":"Options - FatEcto.FatQuery.FatWhere","doc":"- `$select`- Select the fields from `hospital` and `rooms`.\n- `$right_join: :$select`- Select the fields from  `rooms`.\n- `$right_join`- Right join the table `rooms`.\n- `$gte: :$field`- Added the  greaterthanequal attribute in the where query inside join.\n- `$include`- Include the assoication model `doctors` and `patients`.\n- `$not_between`- Added the notbetween in the  where query inside include .\n- `$in`- Added the in attribute in the where query.\n- `$order`- Sort the result based on the order attribute.\n\n\n## => not_in","ref":"FatEcto.FatQuery.FatWhere.html#module-options"},{"type":"module","title":"Parameters - FatEcto.FatQuery.FatWhere","doc":"- `queryable`   - Ecto Queryable that represents your schema name, table name or query.\n- `query_opts`  - Include query options as a map","ref":"FatEcto.FatQuery.FatWhere.html#module-parameters"},{"type":"module","title":"Example - FatEcto.FatQuery.FatWhere","doc":"iex> query_opts = %{\n  ...>  \"$select\" => %{\n  ...>   \"$fields\" => [\"name\", \"location\", \"rating\"],\n  ...>   \"fat_rooms\" => [\"name\", \"floor\"]\n  ...>  },\n  ...>  \"$where\" => %{\"rating\" => %{\"$not_in\" => [10, 20]}},\n  ...>  \"$include\" => %{\n  ...>    \"fat_doctors\" => %{\n  ...>     \"$include\" => [\"fat_patients\"],\n  ...>     \"$where\" => %{\"rating\" => %{\"$not_between\" => [20, 30]}},\n  ...>     \"$order\" => %{\"rating\" => \"$desc\"}\n  ...>    }\n  ...>   },\n  ...>  \"$right_join\" => %{\n  ...>    \"fat_rooms\" => %{\n  ...>      \"$on_field\" => \"id\",\n  ...>      \"$on_table_field\" => \"hospital_id\",\n  ...>      \"$select\" => [\"name\", \"floor\", \"is_active\"],\n  ...>      \"$where\" => %{\"floor\" => %{\"$not_in\" => [5, 15]}}\n  ...>     }\n  ...>   }\n  ...>  }\n  iex> Elixir.MyApp.Query.build!(FatEcto.FatHospital, query_opts)\n  #Ecto.Query  ^30) and ^true, order_by: [desc: f2.rating], limit: ^34, offset: ^0, select: merge(map(f0, [:name, :location, :rating, {:fat_rooms, [:name, :floor]}]), %{^\"fat_rooms\" => map(f1, [:name, :floor, :is_active])}), preload: [[fat_doctors: [:fat_patients]]]>","ref":"FatEcto.FatQuery.FatWhere.html#module-example"},{"type":"module","title":"Options - FatEcto.FatQuery.FatWhere","doc":"- `$select`- Select the fields from `hospital` and `rooms`.\n- `$right_join: :$select`- Select the fields from  `rooms`.\n- `$right_join`- Right join the table `rooms`.\n- `$not_in`- Added the  notin attribute in the where query inside join.\n- `$include`- Include the assoication model `doctors` and `patients`.\n- `$not_between`- Added the notbetween in the  where query inside include .\n- `$not_in`- Added the in attribute in the where query.\n- `$order`- Sort the result based on the order attribute.\n\n\n## => is_nil","ref":"FatEcto.FatQuery.FatWhere.html#module-options"},{"type":"module","title":"Parameters - FatEcto.FatQuery.FatWhere","doc":"- `queryable`   - Ecto Queryable that represents your schema name, table name or query.\n- `query_opts`  - Include query options as a map","ref":"FatEcto.FatQuery.FatWhere.html#module-parameters"},{"type":"module","title":"Example - FatEcto.FatQuery.FatWhere","doc":"iex> query_opts = %{\n  ...>  \"$select\" => %{\n  ...>   \"$fields\" => [\"name\", \"location\", \"rating\"],\n  ...>   \"fat_rooms\" => [\"floor\", \"name\"]\n  ...>  },\n  ...>  \"$where\" => %{\"rating\" => nil},\n  ...>  \"$include\" => %{\n  ...>    \"fat_doctors\" => %{\n  ...>     \"$include\" => [\"fat_patients\"],\n  ...>     \"$where\" => %{\"rating\" => %{\"$between\" => [20, 30]}},\n  ...>     \"$order\" => %{\"experience_years\" => \"$desc\"}\n  ...>    }\n  ...>   },\n  ...>  \"$right_join\" => %{\n  ...>    \"fat_rooms\" => %{\n  ...>      \"$on_field\" => \"id\",\n  ...>      \"$on_table_field\" => \"hospital_id\",\n  ...>      \"$select\" => [\"name\", \"floor\", \"is_active\"],\n  ...>      \"$where\" => %{\"floor\" => %{\"$in\" => [5, 15]}},\n  ...>      \"$order\" => %{\"id\" => \"$asc\"}\n  ...>     }\n  ...>   }\n  ...>  }\n  iex> Elixir.MyApp.Query.build!(FatEcto.FatHospital, query_opts)\n  #Ecto.Query  ^20 and f2.rating < ^30 and ^true, order_by: [asc: f1.id], order_by: [desc: f2.experience_years], limit: ^34, offset: ^0, select: merge(map(f0, [:name, :location, :rating, {:fat_rooms, [:floor, :name]}]), %{^\"fat_rooms\" => map(f1, [:name, :floor, :is_active])}), preload: [[fat_doctors: [:fat_patients]]]>","ref":"FatEcto.FatQuery.FatWhere.html#module-example"},{"type":"module","title":"Options - FatEcto.FatQuery.FatWhere","doc":"- `$select`- Select the fields from `hospital` and `rooms`.\n- `$right_join: :$select`- Select the fields from  `rooms`.\n- `$right_join`- Right join the table `rooms`.\n- `$in`- Added the  in attribute in the where query inside join.\n- `$include`- Include the assoication model `doctors` and `patients`.\n- `$between`- Added the between in the  where query inside include .\n- `nil`- Added the nil attribute in the where query.\n- `$order`- Sort the result based on the order attribute.\n- `$right_join: :$order`- Sort the result based on the order attribute inside join.\n\n\n## => not_null","ref":"FatEcto.FatQuery.FatWhere.html#module-options"},{"type":"module","title":"Parameters - FatEcto.FatQuery.FatWhere","doc":"- `queryable`   - Ecto Queryable that represents your schema name, table name or query.\n- `query_opts`  - Include query options as a map","ref":"FatEcto.FatQuery.FatWhere.html#module-parameters"},{"type":"module","title":"Example - FatEcto.FatQuery.FatWhere","doc":"iex> query_opts = %{\n  ...>  \"$select\" => %{\n  ...>   \"$fields\" => [\"name\", \"location\", \"rating\"],\n  ...>   \"fat_rooms\" => [\"name\", \"floor\"]\n  ...>  },\n  ...>  \"$where\" => %{\"$not_null\" => [\"total_staff\"]},\n  ...>  \"$include\" => %{\n  ...>    \"fat_doctors\" => %{\n  ...>     \"$include\" => [\"fat_patients\"],\n  ...>     \"$where\" => %{\"rating\" => %{\"$in\" => [20, 30]}},\n  ...>     \"$order\" => %{\"rating\" => \"$asc\"},\n  ...>     \"$select\" => [\"name\", \"designation\", \"phone\"]\n  ...>    }\n  ...>   },\n  ...>  \"$right_join\" => %{\n  ...>    \"fat_rooms\" => %{\n  ...>      \"$on_field\" => \"id\",\n  ...>      \"$on_table_field\" => \"hospital_id\",\n  ...>      \"$select\" => [\"name\", \"floor\", \"is_active\"],\n  ...>      \"$where\" => %{\"name\" => nil},\n  ...>      \"$order\" => %{\"id\" => \"$asc\"}\n  ...>     }\n  ...>   }\n  ...> }\n  iex> Elixir.MyApp.Query.build!(FatEcto.FatHospital, query_opts)\n  #Ecto.Query","ref":"FatEcto.FatQuery.FatWhere.html#module-example"},{"type":"module","title":"Options - FatEcto.FatQuery.FatWhere","doc":"- `$select`- Select the fields from `hospital` and `rooms`.\n- `$right_join: :$select`- Select the fields from  `rooms`.\n- `$include: :$select`- Select the fields from  `doctors`.\n- `$right_join`- Right join the table `rooms`.\n- `nil`- Added the  nil attribute in the where query inside join.\n- `$include`- Include the assoication model `doctors` and `patients`.\n- `$in`- Added the in attribute in the  where query inside include .\n- `$not_null`- Added the notnil attribute in the where query.\n- `$order`- Sort the result based on the order attribute.\n- `$right_join: :$order`- Sort the result based on the order attribute inside join.\n\n## => field","ref":"FatEcto.FatQuery.FatWhere.html#module-options"},{"type":"module","title":"Parameters - FatEcto.FatQuery.FatWhere","doc":"- `queryable`   - Ecto Queryable that represents your schema name, table name or query.\n- `query_opts`  - Include query options as a map","ref":"FatEcto.FatQuery.FatWhere.html#module-parameters"},{"type":"module","title":"Example - FatEcto.FatQuery.FatWhere","doc":"iex> query_opts = %{\n  ...> \"$select\" => %{\n  ...>   \"$fields\" => [\"name\", \"location\", \"rating\"],\n  ...>   \"fat_rooms\" => [\"name\", \"floor\"]\n  ...>  },\n  ...>  \"$where\" => %{\"name\" => \"saint claire\"},\n  ...>  \"$group\" => \"rating\",\n  ...>  \"$include\" => %{\n  ...>    \"fat_doctors\" => %{\n  ...>     \"$include\" => [\"fat_patients\"],\n  ...>     \"$where\" => %{\"rating\" => %{\"$gt\" => 5}},\n  ...>     \"$order\" => %{\"experience_years\" => \"$desc\"},\n  ...>     \"$select\" => [\"name\", \"designation\", \"phone\"]\n  ...>    }\n  ...>   },\n  ...>  \"$right_join\" => %{\n  ...>    \"fat_rooms\" => %{\n  ...>      \"$on_field\" => \"id\",\n  ...>      \"$on_table_field\" => \"hospital_id\",\n  ...>      \"$select\" => [\"floor\", \"name\", \"is_active\"],\n  ...>      \"$where\" => %{\"floor\" => 10},\n  ...>      \"$order\" => %{\"id\" => \"$asc\"}\n  ...>     }\n  ...>   }\n  ...> }\n  iex> Elixir.MyApp.Query.build!(FatEcto.FatHospital, query_opts)\n  #Ecto.Query  ^5 and ^true, group_by: [f0.rating], order_by: [asc: f1.id], order_by: [desc: f2.experience_years], limit: ^34, offset: ^0, select: merge(map(f0, [:name, :location, :rating, fat_rooms: [:name, :floor]]), %{\n  ^\"fat_rooms\" => map(f1, [:floor, :name, :is_active])\n}), preload: [fat_doctors: [:fat_patients]]>","ref":"FatEcto.FatQuery.FatWhere.html#module-example"},{"type":"module","title":"Options - FatEcto.FatQuery.FatWhere","doc":"- `$select`- Select the fields from `hospital` and `rooms`.\n- `$right_join: :$select`- Select the fields from  `rooms`.\n- `$include: :$select`- Select the fields from  `doctors`.\n- `$right_join`- Right join the table `rooms`.\n- `$include`- Include the assoication model `doctors` and `patients`.\n- `$gt`- Added the greaterthan attribute in the  where query inside include .\n- `$order`- Sort the result based on the order attribute.\n- `$right_join: :$order`- Sort the result based on the order attribute inside join.\n- `$group`- Added the group_by attribute in the query.","ref":"FatEcto.FatQuery.FatWhere.html#module-options"},{"type":"function","title":"FatEcto.FatQuery.FatWhere.build_where/4","doc":"Build a  `where query` depending on the params.","ref":"FatEcto.FatQuery.FatWhere.html#build_where/4"},{"type":"function","title":"Parameters - FatEcto.FatQuery.FatWhere.build_where/4","doc":"- `queryable`   - Ecto Queryable that represents your schema name, table name or query.\n  - `query_opts`  - Include query options as a map","ref":"FatEcto.FatQuery.FatWhere.html#build_where/4-parameters"},{"type":"function","title":"Examples - FatEcto.FatQuery.FatWhere.build_where/4","doc":"iex> query_opts = %{\n    ...>  \"$select\" => %{\n    ...>    \"$fields\" => [\"name\", \"location\", \"rating\"],\n    ...>    \"fat_rooms\" => [\"name\", \"floor\"]\n    ...>  },\n    ...>  \"$order\" => %{\"id\" => \"$desc\"},\n    ...>  \"$where\" => %{\"location\" => %{\"$not_like\" => \"%addre %\"}},\n    ...>  \"$group\" => \"total_staff\"\n    ...> }\n    iex> Elixir.MyApp.Query.build!(FatEcto.FatHospital, query_opts)\n    #Ecto.Query","ref":"FatEcto.FatQuery.FatWhere.html#build_where/4-examples"},{"type":"function","title":"Options - FatEcto.FatQuery.FatWhere.build_where/4","doc":"- `$select`- Select the fields from `hospital` and `rooms`.\n  - `$where`- Added the where attribute in the query.\n  - `$not_like`- Added the notlike attribute in the where query.\n  - `$group`- Added the group_by attribute in the query.\n  - `$order`- Sort the result based on the order attribute.","ref":"FatEcto.FatQuery.FatWhere.html#build_where/4-options"},{"type":"behaviour","title":"FatEcto.FatQuery.Sortable","doc":"Provides functionality to sort Ecto queries based on user-defined rules.\n\nThis module allows sorting queries using predefined default fields (handled by `FatOrderBy`)\nand custom fields (handled by a fallback function).","ref":"FatEcto.FatQuery.Sortable.html"},{"type":"behaviour","title":"Usage - FatEcto.FatQuery.Sortable","doc":"defmodule MyApp.SortQuery do\n      <!-- needed if you are writing queries in override_sortable -->\n      import Ecto.Query\n      use FatEcto.FatQuery.Sortable,\n        sortable_fields: %{\"id\" => \"$asc\", \"name\" => [\"$asc\", \"$desc\"]},\n        overrideable_fields: [\"custom_field\"]\n\n      @impl true\n      def override_sortable(query, field, operator) do\n        case {field, operator} do\n          {\"custom_field\", \"$asc\"} ->\n            from(q in query, order_by: [asc: fragment(\"?::jsonb->>'custom_field'\", q)])\n          _ ->\n            query\n        end\n      end\n    end","ref":"FatEcto.FatQuery.Sortable.html#module-usage"},{"type":"behaviour","title":"Example - FatEcto.FatQuery.Sortable","doc":"query = from(u in User)\n    sort_params = %{\"id\" => \"$asc\", \"name\" => \"$desc\", \"custom_field\" => \"$asc\"}\n    MyApp.SortQuery.build(query, sort_params)\n\nThis will sort the query by `id` in ascending order, `name` in descending order, and apply custom sorting for `custom_field`.","ref":"FatEcto.FatQuery.Sortable.html#module-example"},{"type":"callback","title":"FatEcto.FatQuery.Sortable.override_sortable/3","doc":"Callback for handling custom sorting logic.\n\nThis function is called for fields defined in `overrideable_fields`. The default behavior is to return the query,\nbut it can be overridden by the using module.","ref":"FatEcto.FatQuery.Sortable.html#c:override_sortable/3"},{"type":"module","title":"FatEcto.FatQuery.SortableHelper","doc":"Provides helper functions for sorting query parameters.","ref":"FatEcto.FatQuery.SortableHelper.html"},{"type":"function","title":"FatEcto.FatQuery.SortableHelper.filter_sortable_fields/2","doc":"Filters sortable fields based on the provided `sortable_fields` map.","ref":"FatEcto.FatQuery.SortableHelper.html#filter_sortable_fields/2"},{"type":"function","title":"Parameters - FatEcto.FatQuery.SortableHelper.filter_sortable_fields/2","doc":"- `filtered_params`: A map of fields and their sorting operators.\n  - `sortable_fields`: A map of allowed fields and their corresponding operators.","ref":"FatEcto.FatQuery.SortableHelper.html#filter_sortable_fields/2-parameters"},{"type":"function","title":"Returns - FatEcto.FatQuery.SortableHelper.filter_sortable_fields/2","doc":"- A filtered map containing only the fields and operators that are allowed.","ref":"FatEcto.FatQuery.SortableHelper.html#filter_sortable_fields/2-returns"},{"type":"module","title":"FatEcto.FatQuery.WhereOr","doc":"This module provides functionality for constructing dynamic `where` or `where not` queries in Ecto.\n\nIt includes aliases for `FatEcto.FatQuery.FatDynamics` and `FatEcto.FatQuery.FatNotDynamics` to simplify the usage of dynamic query generation.","ref":"FatEcto.FatQuery.WhereOr.html"},{"type":"module","title":"Examples - FatEcto.FatQuery.WhereOr","doc":"# Example usage of FatDynamics\n  FatDynamics.some_function(...)\n\n  # Example usage of FatNotDynamics\n  FatNotDynamics.some_function(...)","ref":"FatEcto.FatQuery.WhereOr.html#module-examples"},{"type":"function","title":"FatEcto.FatQuery.WhereOr.map_condition/4","doc":"","ref":"FatEcto.FatQuery.WhereOr.html#map_condition/4"},{"type":"function","title":"FatEcto.FatQuery.WhereOr.or_condition/4","doc":"","ref":"FatEcto.FatQuery.WhereOr.html#or_condition/4"},{"type":"behaviour","title":"FatEcto.FatQuery.Whereable","doc":"Builds queries after filtering fields based on user-provided filterable and overrideable fields.\n\nThis module provides functionality to filter Ecto queries using predefined filterable fields (handled by `FatWhere`)\nand overrideable fields (handled by a fallback function).","ref":"FatEcto.FatQuery.Whereable.html"},{"type":"behaviour","title":"Options - FatEcto.FatQuery.Whereable","doc":"- `filterable_fields`: A map of fields and their allowed operators. Example:\n    %{\n      \"id\" => [\"$eq\", \"$neq\"],\n      \"name\" => [\"$ilike\"]\n    }\n- `overrideable_fields`: A list of fields that can be overridden. Example:\n    [\"name\", \"phone\"]\n- `ignoreable_fields_values`: A map of fields and their ignoreable values. Example:\n    %{\n      \"name\" => [\"%%\", \"\", [], nil],\n      \"phone\" => [\"%%\", \"\", [], nil]\n    }","ref":"FatEcto.FatQuery.Whereable.html#module-options"},{"type":"behaviour","title":"Example Usage - FatEcto.FatQuery.Whereable","doc":"defmodule MyApp.HospitalFilter do\n      use FatEcto.FatQuery.Whereable,\n        filterable_fields: %{\n          \"id\" => [\"$eq\", \"$neq\"]\n        },\n        overrideable_fields: [\"name\", \"phone\"],\n        ignoreable_fields_values: %{\n          \"name\" => [\"%%\", \"\", [], nil],\n          \"phone\" => [\"%%\", \"\", [], nil]\n        }\n\n      import Ecto.Query\n\n      def override_whereable(query, \"name\", \"$ilike\", value) do\n        where(query, [r], ilike(fragment(\"(?)::TEXT\", r.name), ^value))\n      end\n\n      def override_whereable(query, \"phone\", \"$ilike\", value) do\n        where(query, [r], ilike(fragment(\"(?)::TEXT\", r.phone), ^value))\n      end\n\n      def override_whereable(query, _, _, _) do\n        query\n      end\n    end","ref":"FatEcto.FatQuery.Whereable.html#module-example-usage"},{"type":"callback","title":"FatEcto.FatQuery.Whereable.override_whereable/4","doc":"Callback for handling custom filtering logic for overrideable fields.\n\nThis function acts as a fallback for overrideable fields. The default behavior is to return the query,\nbut it can be overridden by the using module.","ref":"FatEcto.FatQuery.Whereable.html#c:override_whereable/4"},{"type":"module","title":"FatEcto.FatQuery.WhereableHelper","doc":"Provides helper functions for filtering and processing query parameters.","ref":"FatEcto.FatQuery.WhereableHelper.html"},{"type":"function","title":"FatEcto.FatQuery.WhereableHelper.filter_filterable_fields/2","doc":"Filters fields in `params` based on the provided `filterable_fields` map.","ref":"FatEcto.FatQuery.WhereableHelper.html#filter_filterable_fields/2"},{"type":"function","title":"Parameters - FatEcto.FatQuery.WhereableHelper.filter_filterable_fields/2","doc":"- params: A map containing the fields, operators, and values to filter.\n- filterable_fields: A map containing allowed fields and their corresponding operators.","ref":"FatEcto.FatQuery.WhereableHelper.html#filter_filterable_fields/2-parameters"},{"type":"function","title":"Returns - FatEcto.FatQuery.WhereableHelper.filter_filterable_fields/2","doc":"A filtered map containing only the fields and operators that are allowed.","ref":"FatEcto.FatQuery.WhereableHelper.html#filter_filterable_fields/2-returns"},{"type":"function","title":"FatEcto.FatQuery.WhereableHelper.filter_overrideable_fields/3","doc":"Filters overrideable fields based on the provided `overrideable_fields` list and `ignoreable_fields_values`.","ref":"FatEcto.FatQuery.WhereableHelper.html#filter_overrideable_fields/3"},{"type":"function","title":"Parameters - FatEcto.FatQuery.WhereableHelper.filter_overrideable_fields/3","doc":"- params: A map containing the fields, operators, and values to filter.\n- overrideable_fields: A list of fields that can be overridden.\n- ignoreable_fields_values: A map containing fields and their ignoreable values.","ref":"FatEcto.FatQuery.WhereableHelper.html#filter_overrideable_fields/3-parameters"},{"type":"function","title":"Returns - FatEcto.FatQuery.WhereableHelper.filter_overrideable_fields/3","doc":"A list of maps containing filtered fields, operators, and values.","ref":"FatEcto.FatQuery.WhereableHelper.html#filter_overrideable_fields/3-returns"},{"type":"function","title":"FatEcto.FatQuery.WhereableHelper.remove_ignoreable_fields/2","doc":"Removes fields from `where_params` if their values match any of the values in `ignoreable_fields_values`.","ref":"FatEcto.FatQuery.WhereableHelper.html#remove_ignoreable_fields/2"},{"type":"function","title":"Parameters - FatEcto.FatQuery.WhereableHelper.remove_ignoreable_fields/2","doc":"- where_params: A map containing the fields, operators, and values to filter.\n- ignoreable_fields_values: A map containing fields and their ignoreable values (can be a single value or a list of values).","ref":"FatEcto.FatQuery.WhereableHelper.html#remove_ignoreable_fields/2-parameters"},{"type":"function","title":"Returns - FatEcto.FatQuery.WhereableHelper.remove_ignoreable_fields/2","doc":"A filtered map with ignoreable fields removed.","ref":"FatEcto.FatQuery.WhereableHelper.html#remove_ignoreable_fields/2-returns"},{"type":"module","title":"FatUtils.Changeset","doc":"Provides utility functions for validating Ecto changesets.\n\nThis module includes functions for validating XOR conditions, requiring specific fields,\nand comparing datetime fields.","ref":"FatUtils.Changeset.html"},{"type":"function","title":"FatUtils.Changeset.add_custom_error/3","doc":"Adds a custom error to the changeset.","ref":"FatUtils.Changeset.html#add_custom_error/3"},{"type":"function","title":"Parameters - FatUtils.Changeset.add_custom_error/3","doc":"- `changeset`: The Ecto changeset.\n- `error_message_title`: The field or title for the error.\n- `error_message`: The error message (default: \"is invalid\").","ref":"FatUtils.Changeset.html#add_custom_error/3-parameters"},{"type":"function","title":"Examples - FatUtils.Changeset.add_custom_error/3","doc":"iex> changeset = cast(%User{}, %{}, [])\n    iex> FatUtils.Changeset.add_custom_error(changeset, :field, \"custom error\")\n    #Ecto.Changeset<...>","ref":"FatUtils.Changeset.html#add_custom_error/3-examples"},{"type":"function","title":"FatUtils.Changeset.require_field_if_present/2","doc":"Makes a field required if another field is present in the changeset.","ref":"FatUtils.Changeset.html#require_field_if_present/2"},{"type":"function","title":"Parameters - FatUtils.Changeset.require_field_if_present/2","doc":"- `changeset`: The Ecto changeset.\n- `if_change_key`: The key to check for presence.\n- `require_key`: The key to make required.","ref":"FatUtils.Changeset.html#require_field_if_present/2-parameters"},{"type":"function","title":"Examples - FatUtils.Changeset.require_field_if_present/2","doc":"iex> changeset = cast(%User{}, %{field1: \"value1\"}, [:field1, :field2])\n    iex> FatUtils.Changeset.require_field_if_present(changeset, if_change_key: :field1, require_key: :field2)\n    #Ecto.Changeset<...>","ref":"FatUtils.Changeset.html#require_field_if_present/2-examples"},{"type":"function","title":"FatUtils.Changeset.validate_at_least_one_field/4","doc":"Validates that at least one of the specified OR keys is present in the changeset.","ref":"FatUtils.Changeset.html#validate_at_least_one_field/4"},{"type":"function","title":"Parameters - FatUtils.Changeset.validate_at_least_one_field/4","doc":"- `changeset`: The Ecto changeset.\n- `record`: The original record (currently unused).\n- `or_keys`: A list of keys to validate.\n- `options`: Additional options (currently unused).","ref":"FatUtils.Changeset.html#validate_at_least_one_field/4-parameters"},{"type":"function","title":"Examples - FatUtils.Changeset.validate_at_least_one_field/4","doc":"iex> changeset = cast(%User{}, %{}, [:field1, :field2])\n    iex> FatUtils.Changeset.validate_at_least_one_field(changeset, %User{}, [:field1, :field2])\n    #Ecto.Changeset<...>","ref":"FatUtils.Changeset.html#validate_at_least_one_field/4-examples"},{"type":"function","title":"FatUtils.Changeset.validate_only_one_field/4","doc":"Validates that only one of the specified keys is present in the changeset.","ref":"FatUtils.Changeset.html#validate_only_one_field/4"},{"type":"function","title":"Parameters - FatUtils.Changeset.validate_only_one_field/4","doc":"- `changeset`: The Ecto changeset.\n- `record`: The original record (currently unused).\n- `single_keys`: A list of keys to validate.\n- `options`: Additional options (currently unused).","ref":"FatUtils.Changeset.html#validate_only_one_field/4-parameters"},{"type":"function","title":"Examples - FatUtils.Changeset.validate_only_one_field/4","doc":"iex> changeset = cast(%User{}, %{field1: \"value1\"}, [:field1, :field2])\n    iex> FatUtils.Changeset.validate_only_one_field(changeset, %User{}, [:field1, :field2])\n    #Ecto.Changeset<...>","ref":"FatUtils.Changeset.html#validate_only_one_field/4-examples"},{"type":"function","title":"FatUtils.Changeset.validate_start_before_end/4","doc":"Validates that a start date/time is before an end date/time.","ref":"FatUtils.Changeset.html#validate_start_before_end/4"},{"type":"function","title":"Parameters - FatUtils.Changeset.validate_start_before_end/4","doc":"- `changeset`: The Ecto changeset.\n- `start_date_key`: The key for the start date/time.\n- `end_date_key`: The key for the end date/time.\n- `options`: Options to customize the error message or specify comparison type (`:time` or `:datetime`).","ref":"FatUtils.Changeset.html#validate_start_before_end/4-parameters"},{"type":"function","title":"Examples - FatUtils.Changeset.validate_start_before_end/4","doc":"iex> changeset = cast(%User{}, %{start_time: ~T[10:00:00], end_time: ~T[09:00:00]}, [:start_time, :end_time])\n    iex> FatUtils.Changeset.validate_start_before_end(changeset, :start_time, :end_time, compare_type: :time)\n    #Ecto.Changeset<...>","ref":"FatUtils.Changeset.html#validate_start_before_end/4-examples"},{"type":"function","title":"FatUtils.Changeset.validate_start_before_or_equal_end/4","doc":"Validates that a start date/time is before or equal to an end date/time.","ref":"FatUtils.Changeset.html#validate_start_before_or_equal_end/4"},{"type":"function","title":"Parameters - FatUtils.Changeset.validate_start_before_or_equal_end/4","doc":"- `changeset`: The Ecto changeset.\n- `start_date_key`: The key for the start date/time.\n- `end_date_key`: The key for the end date/time.\n- `options`: Options to customize the error message or specify comparison type (`:time` or `:datetime`).","ref":"FatUtils.Changeset.html#validate_start_before_or_equal_end/4-parameters"},{"type":"function","title":"Examples - FatUtils.Changeset.validate_start_before_or_equal_end/4","doc":"iex> changeset = cast(%User{}, %{start_time: ~T[10:00:00], end_time: ~T[10:00:00]}, [:start_time, :end_time])\n    iex> FatUtils.Changeset.validate_start_before_or_equal_end(changeset, :start_time, :end_time, compare_type: :time)\n    #Ecto.Changeset<...>","ref":"FatUtils.Changeset.html#validate_start_before_or_equal_end/4-examples"},{"type":"function","title":"FatUtils.Changeset.validate_xor_fields/4","doc":"Validates that only one of the specified XOR keys is present in the changeset.","ref":"FatUtils.Changeset.html#validate_xor_fields/4"},{"type":"function","title":"Parameters - FatUtils.Changeset.validate_xor_fields/4","doc":"- `changeset`: The Ecto changeset.\n- `record`: The original record (used to check if all XOR keys are empty).\n- `xor_keys`: A list of keys to validate as XOR.\n- `options`: Additional options (currently unused).","ref":"FatUtils.Changeset.html#validate_xor_fields/4-parameters"},{"type":"function","title":"Examples - FatUtils.Changeset.validate_xor_fields/4","doc":"iex> changeset = cast(%User{}, %{field1: \"value1\", field2: \"value2\"}, [:field1, :field2])\n    iex> FatUtils.Changeset.validate_xor_fields(changeset, %User{}, [:field1, :field2])\n    #Ecto.Changeset<...>","ref":"FatUtils.Changeset.html#validate_xor_fields/4-examples"},{"type":"module","title":"FatUtils.DateTime","doc":"Provides utility functions for parsing and converting date-time values.\n\nThis module handles parsing of date-time values from integers (Unix timestamps) and\nbinary strings (ISO 8601 format).","ref":"FatUtils.DateTime.html"},{"type":"function","title":"FatUtils.DateTime.parse/1","doc":"Parses a date-time value from an integer (Unix timestamp) or a binary string (ISO 8601 format).\n\nReturns `{:ok, DateTime.t()}` on success or `:error` on failure.","ref":"FatUtils.DateTime.html#parse/1"},{"type":"function","title":"FatUtils.DateTime.parse!/1","doc":"Parses a date-time value from an integer (Unix timestamp) or a binary string (ISO 8601 format).\n\nReturns a `DateTime.t()` on success or `nil` on failure.","ref":"FatUtils.DateTime.html#parse!/1"},{"type":"module","title":"FatUtils.Integer","doc":"Provides utility functions for parsing integers from strings.\n\nThis module handles parsing of integers from strings and ensures consistent return types.","ref":"FatUtils.Integer.html"},{"type":"function","title":"FatUtils.Integer.parse/1","doc":"Parses an integer from a string or returns the integer if already an integer.\n\nReturns `{:ok, integer}` on success or `{:error, nil}` on failure.","ref":"FatUtils.Integer.html#parse/1"},{"type":"function","title":"FatUtils.Integer.parse!/1","doc":"Parses an integer from a string or returns the integer if already an integer.\n\nReturns the parsed integer on success or `nil` on failure.","ref":"FatUtils.Integer.html#parse!/1"},{"type":"module","title":"FatUtils.Map","doc":"Provides utility functions for working with maps and structs.\n\nThis module includes functions for checking keys, values, and performing deep merges.","ref":"FatUtils.Map.html"},{"type":"function","title":"FatUtils.Map.contain_only_allowed_keys?/2","doc":"Checks if the map contains only the allowed keys.","ref":"FatUtils.Map.html#contain_only_allowed_keys?/2"},{"type":"function","title":"Parameters - FatUtils.Map.contain_only_allowed_keys?/2","doc":"- `map`: The map to check.\n- `keys`: A list of allowed keys.","ref":"FatUtils.Map.html#contain_only_allowed_keys?/2-parameters"},{"type":"function","title":"Examples - FatUtils.Map.contain_only_allowed_keys?/2","doc":"iex> FatUtils.Map.contain_only_allowed_keys?(%{a: 1, b: 2}, [:a, :b])\n    true\n    iex> FatUtils.Map.contain_only_allowed_keys?(%{a: 1, c: 3}, [:a, :b])\n    false","ref":"FatUtils.Map.html#contain_only_allowed_keys?/2-examples"},{"type":"function","title":"FatUtils.Map.deep_merge/2","doc":"Deep merges two maps.","ref":"FatUtils.Map.html#deep_merge/2"},{"type":"function","title":"Parameters - FatUtils.Map.deep_merge/2","doc":"- `left`: The first map.\n- `right`: The second map.","ref":"FatUtils.Map.html#deep_merge/2-parameters"},{"type":"function","title":"Examples - FatUtils.Map.deep_merge/2","doc":"iex> FatUtils.Map.deep_merge(%{a: %{b: 1}}, %{a: %{c: 2}})\n    %{a: %{b: 1, c: 2}}","ref":"FatUtils.Map.html#deep_merge/2-examples"},{"type":"function","title":"FatUtils.Map.get_keys_count/2","doc":"Counts the number of specified keys present in the map.","ref":"FatUtils.Map.html#get_keys_count/2"},{"type":"function","title":"Parameters - FatUtils.Map.get_keys_count/2","doc":"- `map`: The map to check.\n- `keys`: A list of keys to count.","ref":"FatUtils.Map.html#get_keys_count/2-parameters"},{"type":"function","title":"Examples - FatUtils.Map.get_keys_count/2","doc":"iex> FatUtils.Map.get_keys_count(%{a: 1, b: 2}, [:a, :b, :c])\n    2","ref":"FatUtils.Map.html#get_keys_count/2-examples"},{"type":"function","title":"FatUtils.Map.has_all_keys?/2","doc":"Checks if all the specified keys are present in the map.","ref":"FatUtils.Map.html#has_all_keys?/2"},{"type":"function","title":"Parameters - FatUtils.Map.has_all_keys?/2","doc":"- `map`: The map to check.\n- `keys`: A list of keys to check for.","ref":"FatUtils.Map.html#has_all_keys?/2-parameters"},{"type":"function","title":"Examples - FatUtils.Map.has_all_keys?/2","doc":"iex> FatUtils.Map.has_all_keys?(%{a: 1, b: 2}, [:a, :b])\n    true\n    iex> FatUtils.Map.has_all_keys?(%{a: 1}, [:a, :b])\n    false","ref":"FatUtils.Map.html#has_all_keys?/2-examples"},{"type":"function","title":"FatUtils.Map.has_all_keys_exclusive?/2","doc":"Checks if the map contains only the specified keys and no others.","ref":"FatUtils.Map.html#has_all_keys_exclusive?/2"},{"type":"function","title":"Parameters - FatUtils.Map.has_all_keys_exclusive?/2","doc":"- `map`: The map to check.\n- `keys`: A list of allowed keys.","ref":"FatUtils.Map.html#has_all_keys_exclusive?/2-parameters"},{"type":"function","title":"Examples - FatUtils.Map.has_all_keys_exclusive?/2","doc":"iex> FatUtils.Map.has_all_keys_exclusive?(%{a: 1, b: 2}, [:a, :b])\n    true\n    iex> FatUtils.Map.has_all_keys_exclusive?(%{a: 1, c: 3}, [:a, :b])\n    false","ref":"FatUtils.Map.html#has_all_keys_exclusive?/2-examples"},{"type":"function","title":"FatUtils.Map.has_all_val_equal_to?/3","doc":"Checks if all the specified keys in the map have the given value.","ref":"FatUtils.Map.html#has_all_val_equal_to?/3"},{"type":"function","title":"Parameters - FatUtils.Map.has_all_val_equal_to?/3","doc":"- `map`: The map to check.\n- `keys`: A list of keys to check.\n- `equal_to`: The value to compare against.","ref":"FatUtils.Map.html#has_all_val_equal_to?/3-parameters"},{"type":"function","title":"Examples - FatUtils.Map.has_all_val_equal_to?/3","doc":"iex> FatUtils.Map.has_all_val_equal_to?(%{a: 1, b: 1}, [:a, :b], 1)\n    true\n    iex> FatUtils.Map.has_all_val_equal_to?(%{a: 1, b: 2}, [:a, :b], 1)\n    false","ref":"FatUtils.Map.html#has_all_val_equal_to?/3-examples"},{"type":"function","title":"FatUtils.Map.has_any_of_keys?/2","doc":"Checks if the map contains any of the specified keys.","ref":"FatUtils.Map.html#has_any_of_keys?/2"},{"type":"function","title":"Parameters - FatUtils.Map.has_any_of_keys?/2","doc":"- `map`: The map to check.\n- `keys`: A list of keys to check for.","ref":"FatUtils.Map.html#has_any_of_keys?/2-parameters"},{"type":"function","title":"Examples - FatUtils.Map.has_any_of_keys?/2","doc":"iex> FatUtils.Map.has_any_of_keys?(%{a: 1}, [:a, :b])\n    true\n    iex> FatUtils.Map.has_any_of_keys?(%{c: 3}, [:a, :b])\n    false","ref":"FatUtils.Map.html#has_any_of_keys?/2-examples"},{"type":"module","title":"FatUtils.Network","doc":"Provides utility functions for working with network-related tasks.\n\nThis module includes functions for retrieving local network addresses.","ref":"FatUtils.Network.html"},{"type":"function","title":"FatUtils.Network.local_address/0","doc":"Retrieves the local network address.","ref":"FatUtils.Network.html#local_address/0"},{"type":"function","title":"Examples - FatUtils.Network.local_address/0","doc":"iex> FatUtils.Network.local_address()\n    \"192.168.1.100\"","ref":"FatUtils.Network.html#local_address/0-examples"},{"type":"function","title":"Returns - FatUtils.Network.local_address/0","doc":"- A string representing the local network address, or `nil` if the address cannot be determined.","ref":"FatUtils.Network.html#local_address/0-returns"},{"type":"module","title":"FatUtils.String","doc":"Provides utility functions for generating random strings.\n\nThis module includes functions for generating random strings of specified lengths\nand from specific character sets.","ref":"FatUtils.String.html"},{"type":"function","title":"FatUtils.String.random/1","doc":"Generates a random string of the specified length.","ref":"FatUtils.String.html#random/1"},{"type":"function","title":"Parameters - FatUtils.String.random/1","doc":"- `length`: The length of the random string (default: 8).","ref":"FatUtils.String.html#random/1-parameters"},{"type":"function","title":"Examples - FatUtils.String.random/1","doc":"iex> FatUtils.String.random()\n    \"aB3dEfG1\"\n\n    iex> FatUtils.String.random(12)\n    \"xYz1aB2cD3eF\"","ref":"FatUtils.String.html#random/1-examples"},{"type":"function","title":"FatUtils.String.random_of/2","doc":"Generates a random string of the specified length using a custom character set.","ref":"FatUtils.String.html#random_of/2"},{"type":"function","title":"Parameters - FatUtils.String.random_of/2","doc":"- `length`: The length of the random string.\n- `char_set`: A list of characters to use for generating the string (default: A-Z).","ref":"FatUtils.String.html#random_of/2-parameters"},{"type":"function","title":"Examples - FatUtils.String.random_of/2","doc":"iex> FatUtils.String.random_of(10)\n    \"ABCDEFGHIJ\"\n\n    iex> FatUtils.String.random_of(5, [\"a\", \"b\", \"c\"])\n    \"abcba\"","ref":"FatUtils.String.html#random_of/2-examples"},{"type":"module","title":"FatUtils.Table","doc":"Provides utility functions for working with database tables.\n\nThis module includes functions to generate SQL queries for common table operations,\nsuch as resetting the ID sequence of a table.","ref":"FatUtils.Table.html"},{"type":"function","title":"FatUtils.Table.reset_id_seq_query/2","doc":"Generates a SQL query to reset the ID sequence of a given table.","ref":"FatUtils.Table.html#reset_id_seq_query/2"},{"type":"function","title":"Parameters - FatUtils.Table.reset_id_seq_query/2","doc":"- `table`: The name of the table as a string or atom.\n  - `id`: The name of the ID column as a string or atom. Defaults to `\"id\"`.","ref":"FatUtils.Table.html#reset_id_seq_query/2-parameters"},{"type":"function","title":"Examples - FatUtils.Table.reset_id_seq_query/2","doc":"iex> FatUtils.Table.reset_id_seq_query(\"users\")\n    \"SELECT setval('users_id_seq', (SELECT MAX(id) from \"users\"));\"\n\n    iex> FatUtils.Table.reset_id_seq_query(\"posts\", \"post_id\")\n    \"SELECT setval('posts_post_id_seq', (SELECT MAX(post_id) from \"posts\"));\"","ref":"FatUtils.Table.html#reset_id_seq_query/2-examples"},{"type":"function","title":"Notes - FatUtils.Table.reset_id_seq_query/2","doc":"- Ensure that the table has no records or that the sequence reset is appropriate for your use case.\n- This function only generates the SQL query. You need to execute it using your database driver or migration tool.","ref":"FatUtils.Table.html#reset_id_seq_query/2-notes"},{"type":"module","title":"FatUtils.UUID","doc":"Provides utility functions for working with UUIDs.\n\nThis module includes functions to validate and parse UUIDs from a map of parameters.","ref":"FatUtils.UUID.html"},{"type":"function","title":"FatUtils.UUID.parse/3","doc":"Parses and validates UUIDs in a map of parameters.\n\nThis function takes a map of parameters, a list of fields that should contain UUIDs,\nand an optional list of options. It returns a tuple containing a list of invalid UUID fields\nand a map of valid parameters.","ref":"FatUtils.UUID.html#parse/3"},{"type":"function","title":"Parameters - FatUtils.UUID.parse/3","doc":"- `params`: A map of parameters.\n  - `list_of_uuid_fields`: A list of fields (keys) in the map that should contain UUIDs.\n  - `options`: A keyword list of options. Supported options:\n    - `:valid_values`: A list of values that are considered valid without UUID validation.","ref":"FatUtils.UUID.html#parse/3-parameters"},{"type":"function","title":"Returns - FatUtils.UUID.parse/3","doc":"- `{invalid_uuids, valid_params}`: A tuple where:\n    - `invalid_uuids` is a list of fields that contain invalid UUIDs.\n    - `valid_params` is a map of parameters with valid UUIDs.","ref":"FatUtils.UUID.html#parse/3-returns"},{"type":"function","title":"Examples - FatUtils.UUID.parse/3","doc":"iex> params = %{user_id: \"123e4567-e89b-12d3-a456-426614174000\", post_id: \"invalid-uuid\"}\n    iex> FatUtils.UUID.parse(params, [:user_id, :post_id])\n    {[:post_id], %{user_id: \"123e4567-e89b-12d3-a456-426614174000\", post_id: \"invalid-uuid\"}}\n\n    iex> params = %{user_id: \"123e4567-e89b-12d3-a456-426614174000\", role: \"admin\"}\n    iex> FatUtils.UUID.parse(params, [:user_id], valid_values: [\"admin\"])\n    {[], %{user_id: \"123e4567-e89b-12d3-a456-426614174000\", role: \"admin\"}}","ref":"FatUtils.UUID.html#parse/3-examples"},{"type":"module","title":"PaginatorDocs","doc":"Paginator module can limit the number of records returned and also apply the offset and return meta information. You can use it inside a module.\n\n```\n  use FatEcto.FatPaginator, max_limit: 10, default_limit: 5\n```","ref":"PaginatorDocs.html"},{"type":"function","title":"PaginatorDocs.paginate/2","doc":"Paginates the given query with the provided parameters.","ref":"PaginatorDocs.html#paginate/2"},{"type":"function","title":"Parameters - PaginatorDocs.paginate/2","doc":"- `query`: The Ecto query to paginate.\n- `params`: A keyword list or map containing `limit` and `skip` values.","ref":"PaginatorDocs.html#paginate/2-parameters"},{"type":"function","title":"Returns - PaginatorDocs.paginate/2","doc":"A map containing:\n- `data_query`: The paginated query.\n- `count_query`: The query to count the total number of records.\n- `limit`: The limit value used for pagination.\n- `skip`: The skip value used for pagination.","ref":"PaginatorDocs.html#paginate/2-returns"},{"type":"function","title":"Examples - PaginatorDocs.paginate/2","doc":"iex> import Ecto.Query\n    iex> query = from(h in FatEcto.FatHospital)\n    iex> result = FatEcto.Sample.Pagination.paginate(query, limit: 10, skip: 0)\n    iex> %{data_query: data_query, count_query: count_query, limit: limit, skip: skip} = result\n    iex> limit\n    10\n    iex> skip\n    0\n    iex> data_query\n    #Ecto.Query \n    iex> count_query\n    #Ecto.Query","ref":"PaginatorDocs.html#paginate/2-examples"},{"type":"module","title":"SanitizeRecordsDocs","doc":"This module sanitize the response by removing structs that are not loaded alognwith meta. It supports lists of maps, tuples and map.\n\n```\n use FatEcto.DataSanitizer, otp_app: :app_name, encoder_library: encode_library\n```","ref":"SanitizeRecordsDocs.html"},{"type":"function","title":"SanitizeRecordsDocs.sanitize/2","doc":"Sanitizes the given record or list of records.","ref":"SanitizeRecordsDocs.html#sanitize/2"},{"type":"function","title":"Parameters - SanitizeRecordsDocs.sanitize/2","doc":"- `record/records`: A map, list of maps, or tuple.\n- `opts`: A keyword list of options:\n  - `:mask`: A list of keys whose values should be masked (e.g., `[card_number: \"****\"]`).\n  - `:remove`: A list of keys to remove from the final result.\n  - `:only`: A list of keys to include in the final result (all others are excluded).\n  - `:except`: A list of keys to exclude from the final result.","ref":"SanitizeRecordsDocs.html#sanitize/2-parameters"},{"type":"function","title":"Examples - SanitizeRecordsDocs.sanitize/2","doc":"iex> record = %{name: \"John\", card_number: \"1234-5678-9012-3456\", ssn: \"123-45-6789\"}\n    iex> sanitized = FatEcto.TestRecordUtils.sanitize(record, mask: [card_number: \"****\"], remove: [:ssn])\n    iex> sanitized\n    %{name: \"John\", card_number: \"****\"}","ref":"SanitizeRecordsDocs.html#sanitize/2-examples"},{"type":"extras","title":"FatEcto","doc":"# FatEcto\n\n\n[![Build Status](https://github.com/tanweerdev/fat_ecto/workflows/tests/badge.svg)](https://github.com/parroty/excoveralls/actions)\n[![Coverage Status](https://coveralls.io/repos/github/tanweerdev/fat_ecto/badge.svg?branch=master)](https://coveralls.io/github/tanweerdev/fat_ecto?branch=master)\n[![hex.pm version](https://img.shields.io/hexpm/v/fat_ecto.svg)](https://hex.pm/packages/fat_ecto)\n[![hex.pm downloads](https://img.shields.io/hexpm/dt/fat_ecto.svg)](https://hex.pm/packages/fat_ecto)\n[![hex.pm license](https://img.shields.io/hexpm/l/fat_ecto.svg)](https://github.com/tanweerdev/fat_ecto/blob/master/LICENSE)\n[![Last Updated](https://img.shields.io/github/last-commit/tanweerdev/fat_ecto.svg)](https://github.com/tanweerdev/fat_ecto/commits/master)","ref":"readme.html"},{"type":"extras","title":"Description - FatEcto","doc":"FatEcto is an Elixir package designed to simplify and enhance Ecto query building, pagination, sorting, and data sanitization. It provides a set of utilities and modules that make it easier to work with Ecto in your Elixir applications.","ref":"readme.html#description"},{"type":"extras","title":"Installation - FatEcto","doc":"Add `fat_ecto` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    # Check https://hexdocs.pm/fat_ecto for latest version\n    {:fat_ecto, \"~> 1.0.0\"}\n  ]\nend\n```\n\nThen, run mix deps.get to install the package.","ref":"readme.html#installation"},{"type":"extras","title":"Modules - FatEcto","doc":"","ref":"readme.html#modules"},{"type":"extras","title":"FatEcto.FatQuery.Whereable - FatEcto","doc":"The Whereable module provides functionality to filter Ecto queries using predefined filterable and overrideable fields.\n\n#### Usage\n\n```elixir\ndefmodule MyApp.HospitalFilter do\n  use FatEcto.FatQuery.Whereable,\n    filterable_fields: %{\n      \"id\" => [\"$eq\", \"$neq\"]\n    },\n    overrideable_fields: [\"name\", \"phone\"],\n    ignoreable_fields_values: %{\n      \"name\" => [\"%%\", \"\", [], nil],\n      \"phone\" => [\"%%\", \"\", [], nil]\n    }\n\n  import Ecto.Query\n\n  def override_whereable(query, \"name\", \"$ilike\", value) do\n    where(query, [r], ilike(fragment(\"(?)::TEXT\", r.name), ^value))\n  end\n\n  def override_whereable(query, \"phone\", \"$ilike\", value) do\n    where(query, [r], ilike(fragment(\"(?)::TEXT\", r.phone), ^value))\n  end\n\n  def override_whereable(query, _, _, _) do\n    query\n  end\nend\n```","ref":"readme.html#fatecto-fatquery-whereable"},{"type":"extras","title":"FatEcto.FatQuery.Sortable - FatEcto","doc":"The Sortable module allows sorting Ecto queries based on user-defined rules.\n\n#### Usage\n\n```elixir\ndefmodule MyApp.SortQuery do\n  import Ecto.Query\n  use FatEcto.FatQuery.Sortable,\n    sortable_fields: %{\"id\" => \"$asc\", \"name\" => [\"$asc\", \"$desc\"]},\n    overrideable_fields: [\"custom_field\"]\n\n  @impl true\n  def override_sortable(query, field, operator) do\n    case {field, operator} do\n      {\"custom_field\", \"$asc\"} ->\n        from(q in query, order_by: [asc: fragment(\"?::jsonb->>'custom_field'\", q)])\n      _ ->\n        query\n    end\n  end\nend\n```","ref":"readme.html#fatecto-fatquery-sortable"},{"type":"extras","title":"FatEcto.FatPaginator - FatEcto","doc":"The FatPaginator module provides pagination functionality for Ecto queries.\n\n#### Usage\n\n```elixir\ndefmodule MyApp.MyContext do\n  use FatEcto.FatPaginator, repo: MyApp.Repo\n\n  # Custom functions can be added here\nend\n```","ref":"readme.html#fatecto-fatpaginator"},{"type":"extras","title":"FatEcto.DataSanitizer - FatEcto","doc":"The DataSanitizer module provides functionality to sanitize records and convert data into views.\n\n#### Usage\n\n```elixir\ndefmodule MyApp.MyContext do\n  use FatEcto.DataSanitizer\n\n  # Custom functions can be added here\nend\n```","ref":"readme.html#fatecto-datasanitizer"},{"type":"extras","title":"Utilities - FatEcto","doc":"FatEcto also includes a set of utility functions for various purposes, such as changeset validation, datetime handling, map manipulation, and table operations. These utilities are designed to make common tasks easier and more consistent.\n\nExample Usage\n\n```elixir\n# Example of using a utility function\nalias FatEcto.Utils.MapUtils\n\ndata = %{name: \"John\", age: 30, email: \"john@example.com\"}\nfiltered_data = MapUtils.filter_keys(data, [:name, :email])\n```","ref":"readme.html#utilities"},{"type":"extras","title":"Contributing - FatEcto","doc":"Contributions are welcome! Please feel free to submit issues or pull requests.\n\nLicense\nMIT License\n\nCopyright (c) 2023 Muhammad Tanweer\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.\n\nsee [Docs](https://hexdocs.pm/fat_ecto/) for more details.","ref":"readme.html#contributing"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}